@@ -40,4 +40,12 @@ func; \
 ARMNN_NO_DEPRECATE_WARN_END
 
 #define ARMNN_DEPRECATED [[deprecated]]
-#define ARMNN_DEPRECATED_MSG(message) [[deprecated(message)]]
\ No newline at end of file
+#define ARMNN_DEPRECATED_MSG(message) [[deprecated(message)]]
+
+#if defined(__GNUC__) && (__GNUC__ < 6)
+#   define ARMNN_DEPRECATED_ENUM
+#   define ARMNN_DEPRECATED_ENUM_MSG(message)
+#else
+#   define ARMNN_DEPRECATED_ENUM ARMNN_DEPRECATED
+#   define ARMNN_DEPRECATED_ENUM_MSG(message) ARMNN_DEPRECATED_MSG(message)
+#endif
\ No newline at end of file
