@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #pragma once
@@ -14,7 +14,6 @@
 #include <functional>
 #include <memory>
 #include <vector>
-#include "ArmNN.hpp"
 
 namespace armnn
 {
@@ -28,6 +27,7 @@ protected:
     virtual ~ILayerSupport() {}
 
 public:
+    ARMNN_DEPRECATED_MSG("Use IsElementwiseUnarySupported instead")
     virtual bool IsAbsSupported(const TensorInfo& input,
                                 const TensorInfo& output,
                                 Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
@@ -75,6 +75,14 @@ public:
     virtual bool IsConstantSupported(const TensorInfo& output,
                                      Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
 
+    virtual bool IsConvertBf16ToFp32Supported(const TensorInfo& input,
+                                              const TensorInfo& output,
+                                              Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
+
+    virtual bool IsConvertFp32ToBf16Supported(const TensorInfo& input,
+                                              const TensorInfo& output,
+                                              Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
+
     virtual bool IsConvertFp16ToFp32Supported(const TensorInfo& input,
                                               const TensorInfo& output,
                                               Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
@@ -111,11 +119,15 @@ public:
                                        const TensorInfo& output,
                                        Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
 
-    virtual bool IsDetectionPostProcessSupported(
-                     const TensorInfo& input0,
-                     const TensorInfo& input1,
-                     const DetectionPostProcessDescriptor& descriptor,
-                     Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
+    virtual bool IsDetectionPostProcessSupported(const TensorInfo& boxEncodings,
+                                                 const TensorInfo& scores,
+                                                 const TensorInfo& anchors,
+                                                 const TensorInfo& detectionBoxes,
+                                                 const TensorInfo& detectionClasses,
+                                                 const TensorInfo& detectionScores,
+                                                 const TensorInfo& numDetections,
+                                                 const DetectionPostProcessDescriptor& descriptor,
+                                                 Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const =0;
 
     virtual bool IsDilatedDepthwiseConvolutionSupported(
                     const TensorInfo& input,
@@ -130,6 +142,11 @@ public:
                                      const TensorInfo& output,
                                      Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
 
+    virtual bool IsElementwiseUnarySupported(const TensorInfo& input,
+                                             const TensorInfo& output,
+                                             const ElementwiseUnaryDescriptor& descriptor,
+                                             Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
+
     ARMNN_DEPRECATED_MSG("Use IsComparisonSupported instead")
     virtual bool IsEqualSupported(const TensorInfo& input0,
                                   const TensorInfo& input1,
@@ -140,6 +157,11 @@ public:
                                              const FakeQuantizationDescriptor& descriptor,
                                              Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
 
+    virtual bool IsFillSupported(const TensorInfo& input,
+                                 const TensorInfo& output,
+                                 const FillDescriptor& descriptor,
+                                 Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
+
     virtual bool IsFloorSupported(const TensorInfo& input,
                                   const TensorInfo& output,
                                   Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
@@ -151,11 +173,18 @@ public:
                                            const FullyConnectedDescriptor& descriptor,
                                            Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
 
+    ARMNN_DEPRECATED_MSG("Use IsGatherSupported with descriptor instead")
     virtual bool IsGatherSupported(const TensorInfo& input0,
                                    const TensorInfo& input1,
                                    const TensorInfo& output,
                                    Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
 
+    virtual bool IsGatherSupported(const TensorInfo& input0,
+                                   const TensorInfo& input1,
+                                   const TensorInfo& output,
+                                   const GatherDescriptor& descriptor,
+                                   Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
+
     ARMNN_DEPRECATED_MSG("Use IsComparisonSupported instead")
     virtual bool IsGreaterSupported(const TensorInfo& input0,
                                     const TensorInfo& input1,
@@ -267,6 +296,16 @@ public:
                                      const TensorInfo& output,
                                      Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
 
+    virtual bool IsQLstmSupported(const TensorInfo& input,
+                                  const TensorInfo& previousOutputIn,
+                                  const TensorInfo& previousCellStateIn,
+                                  const TensorInfo& outputStateOut,
+                                  const TensorInfo& cellStateOut,
+                                  const TensorInfo& output,
+                                  const QLstmDescriptor& descriptor,
+                                  const LstmInputParamsInfo& paramsInfo,
+                                  Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
+
     virtual bool IsQuantizedLstmSupported(const TensorInfo& input,
                                           const TensorInfo& previousCellStateIn,
                                           const TensorInfo& previousOutputIn,
@@ -275,10 +314,9 @@ public:
                                           const QuantizedLstmInputParamsInfo& paramsInfo,
                                           Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
 
-    ARMNN_DEPRECATED_MSG("Use IsReshapeSupported with output tensor info argument instead")
-    virtual bool IsReshapeSupported(const TensorInfo& input,
-                                    const ReshapeDescriptor& descriptor,
-                                    Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
+    virtual bool IsRankSupported(const TensorInfo& input,
+                                 const TensorInfo& output,
+                                 Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
 
     virtual bool IsReshapeSupported(const TensorInfo& input,
                                     const TensorInfo& output,
@@ -295,6 +333,7 @@ public:
                                    const ResizeDescriptor& descriptor,
                                    Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
 
+    ARMNN_DEPRECATED_MSG("Use IsElementwiseUnarySupported instead")
     virtual bool IsRsqrtSupported(const TensorInfo& input,
                                   const TensorInfo& output,
                                   Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
@@ -364,6 +403,11 @@ public:
         const Optional<TensorInfo>& biases,
         Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
 
+    virtual bool IsTransposeSupported(const TensorInfo& input,
+                                      const TensorInfo& output,
+                                      const TransposeDescriptor& descriptor,
+                                      Optional<std::string&> reasonIfUnsupported = EmptyOptional()) const = 0;
+
 }; // class ILayerSupport
 
 using ILayerSupportSharedPtr = std::shared_ptr<ILayerSupport>;
