@@ -5,14 +5,16 @@
 
 #pragma once
 
-#include "armnn/Types.hpp"
-#include "Half.hpp"
+#include <armnn/Types.hpp>
+
+#include <BFloat16.hpp>
+#include <Half.hpp>
 
 namespace armnn
 {
 
 template<typename T>
-bool CompatibleTypes(DataType dataType)
+bool CompatibleTypes(DataType)
 {
     return false;
 }
@@ -29,16 +31,32 @@ inline bool CompatibleTypes<Half>(DataType dataType)
     return dataType == DataType::Float16;
 }
 
+template<>
+inline bool CompatibleTypes<BFloat16>(DataType dataType)
+{
+    return dataType == DataType::BFloat16;
+}
+
 template<>
 inline bool CompatibleTypes<uint8_t>(DataType dataType)
 {
-    return dataType == DataType::Boolean || dataType == DataType::QuantisedAsymm8;
+    return dataType == DataType::Boolean || dataType == DataType::QAsymmU8;
+}
+
+template<>
+inline bool CompatibleTypes<int8_t>(DataType dataType)
+{
+    ARMNN_NO_DEPRECATE_WARN_BEGIN
+    return dataType == DataType::QSymmS8
+        || dataType == DataType::QuantizedSymm8PerAxis
+        || dataType == DataType::QAsymmS8;
+    ARMNN_NO_DEPRECATE_WARN_END
 }
 
 template<>
 inline bool CompatibleTypes<int16_t>(DataType dataType)
 {
-    return dataType == DataType::QuantisedSymm16;
+    return dataType == DataType::QSymmS16;
 }
 
 template<>
