@@ -14,6 +14,9 @@ namespace armnn
 class DeviceSpec : public IDeviceSpec
 {
 public:
+    DeviceSpec()
+    {}
+
     DeviceSpec(const BackendIdSet& supportedBackends)
         : m_SupportedBackends{supportedBackends} {}
 
@@ -24,14 +27,32 @@ public:
         return m_SupportedBackends;
     }
 
-    void AddSupportedBackends(const BackendIdSet& backendIds)
+    void AddSupportedBackends(const BackendIdSet& backendIds, bool isDynamic = false)
     {
         m_SupportedBackends.insert(backendIds.begin(), backendIds.end());
+        if (isDynamic)
+        {
+            m_DynamicBackends.insert(backendIds.begin(), backendIds.end());
+        }
+    }
+
+    void ClearDynamicBackends()
+    {
+        for (const auto& id : m_DynamicBackends)
+        {
+            m_SupportedBackends.erase(id);
+        }
+        m_DynamicBackends.clear();
+    }
+
+    const BackendIdSet& GetDynamicBackends() const
+    {
+        return m_DynamicBackends;
     }
 
 private:
-    DeviceSpec() = delete;
     BackendIdSet m_SupportedBackends;
+    BackendIdSet m_DynamicBackends;
 };
 
 } // namespace armnn
