@@ -17,11 +17,11 @@ class IExecutionFrame
 {
 
 public:
-    ~IExecutionFrame() {}
+    virtual ~IExecutionFrame() {}
 
     virtual IExecutionFrame* ExecuteWorkloads(IExecutionFrame* previousFrame) = 0;
     virtual void PostAllocationConfigure() {};
-    virtual void RegisterDebugCallback(const DebugCallbackFunction& func) {};
+    virtual void RegisterDebugCallback(const DebugCallbackFunction&) {};
 };
 
 class ExecutionFrame: public IExecutionFrame
@@ -39,4 +39,4 @@ private:
     IExecutionFrame* m_NextExecutionFrame = nullptr;
 };
 
-}
\ No newline at end of file
+}
