@@ -1,5 +1,5 @@
-﻿//
-// Copyright © 2017 Arm Ltd. All rights reserved.
+//
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -7,26 +7,29 @@
 #include "Layer.hpp"
 #include "Graph.hpp"
 #include "Network.hpp"
+#include <Processes.hpp>
 #include "Runtime.hpp"
 #include "Profiling.hpp"
 #include "HeapProfiling.hpp"
 
 #include <armnn/BackendRegistry.hpp>
+#include <armnn/Logging.hpp>
+#include <armnn/utility/Assert.hpp>
 
 #include <backendsCommon/CpuTensorHandle.hpp>
-#include <backendsCommon/IMemoryManager.hpp>
+#include <armnn/backends/IMemoryManager.hpp>
 #include <backendsCommon/MemCopyWorkload.hpp>
 #include <backendsCommon/MemSyncWorkload.hpp>
 
-#include <boost/polymorphic_cast.hpp>
-#include <boost/assert.hpp>
+#include <LabelsAndEventClasses.hpp>
+
 #include <boost/format.hpp>
-#include <boost/log/trivial.hpp>
 
 namespace armnn
 {
 
 using namespace std;
+using namespace armnn::profiling;
 
 namespace
 {
@@ -39,25 +42,63 @@ std::string ToErrorMessage(const char * prefix, const ExceptionType & error)
     return ss.str();
 }
 
+void AddLayerStructure(std::unique_ptr<TimelineUtilityMethods>& timelineUtils,
+                       const Layer& layer,
+                       ProfilingGuid networkGuid)
+{
+    // Add layer to the post-optimisation network structure
+    std::string layerName = layer.GetNameStr().empty() ? "<Unnamed>" : layer.GetNameStr();
+    timelineUtils->CreateNamedTypedChildEntity(layer.GetGuid(),
+                                               networkGuid,
+                                               layerName,
+                                               LabelsAndEventClasses::LAYER_GUID);
+    for (auto&& input : layer.GetInputSlots())
+    {
+        const IOutputSlot* source = input.GetConnectedOutputSlot();
+        ARMNN_ASSERT(source != NULL);
+        timelineUtils->CreateConnectionRelationship(ProfilingRelationshipType::RetentionLink,
+                                                    source->GetOwningLayerGuid(),
+                                                    layer.GetGuid());
+    }
+}
+
+void AddWorkloadStructure(std::unique_ptr<TimelineUtilityMethods>& timelineUtils,
+                          std::unique_ptr<IWorkload>& workload,
+                          const Layer& layer)
+{
+    // Add workload to the post-optimisation network structure
+    timelineUtils->CreateTypedEntity(workload->GetGuid(), LabelsAndEventClasses::WORKLOAD_GUID);
+    timelineUtils->MarkEntityWithLabel(workload->GetGuid(),
+                                       layer.GetBackendId().Get(),
+                                       LabelsAndEventClasses::BACKENDID_GUID);
+
+    // Link the workload to the layer
+    timelineUtils->CreateRelationship(ProfilingRelationshipType::RetentionLink,
+                                      layer.GetGuid(),
+                                      workload->GetGuid(),
+                                      LabelsAndEventClasses::CHILD_GUID);
+}
+
 } // anonymous
 
 std::unique_ptr<LoadedNetwork> LoadedNetwork::MakeLoadedNetwork(std::unique_ptr<OptimizedNetwork> net,
                                                                 std::string& errorMessage,
-                                                                const INetworkProperties& networkProperties)
+                                                                const INetworkProperties& networkProperties,
+                                                                profiling::ProfilingService&  profilingService)
 {
     std::unique_ptr<LoadedNetwork> loadedNetwork;
 
     auto Fail = [&](const std::exception& error) -> std::unique_ptr<LoadedNetwork>
     {
         errorMessage = ToErrorMessage("An error occurred when preparing the network workloads: ", error);
-        BOOST_LOG_TRIVIAL(error) << errorMessage;
+        ARMNN_LOG(error) << errorMessage;
 
         return std::unique_ptr<LoadedNetwork>();
     };
 
     try
     {
-        loadedNetwork.reset(new LoadedNetwork(std::move(net), networkProperties));
+        loadedNetwork.reset(new LoadedNetwork(std::move(net), networkProperties, profilingService));
     }
     catch (const armnn::RuntimeException& error)
     {
@@ -76,10 +117,13 @@ std::unique_ptr<LoadedNetwork> LoadedNetwork::MakeLoadedNetwork(std::unique_ptr<
 }
 
 LoadedNetwork::LoadedNetwork(std::unique_ptr<OptimizedNetwork> net,
-                             const INetworkProperties& networkProperties) :
+                             const INetworkProperties& networkProperties,
+                             profiling::ProfilingService&  profilingService) :
                              m_OptimizedNetwork(std::move(net)),
                              m_IsImportEnabled(networkProperties.m_ImportEnabled),
-                             m_IsExportEnabled(networkProperties.m_ExportEnabled)
+                             m_IsExportEnabled(networkProperties.m_ExportEnabled),
+                             m_TensorHandleFactoryRegistry(),
+                             m_ProfilingService(profilingService)
 {
     // Create a profiler and register it for the current thread.
     m_Profiler = std::make_shared<Profiler>();
@@ -102,8 +146,6 @@ LoadedNetwork::LoadedNetwork(std::unique_ptr<OptimizedNetwork> net,
 
             if (backend->SupportsTensorAllocatorAPI())
             {
-                backend->RegisterTensorHandleFactories(m_TensorHandleFactoryRegistry);
-
                 auto workloadFactory = backend->CreateWorkloadFactory(m_TensorHandleFactoryRegistry);
                 m_WorkloadFactories.emplace(
                     std::make_pair(backendId, std::make_pair(std::move(workloadFactory), nullptr)));
@@ -126,6 +168,7 @@ LoadedNetwork::LoadedNetwork(std::unique_ptr<OptimizedNetwork> net,
         switch (layer->GetType())
         {
         case LayerType::Input:
+        case LayerType::MemImport:
             {
                 // If IsImportEnabled is true then we need to set IsMemoryManaged to false when creating TensorHandles
                 layer->CreateTensorHandles(m_TensorHandleFactoryRegistry, workloadFactory, !m_IsImportEnabled);
@@ -149,9 +192,30 @@ LoadedNetwork::LoadedNetwork(std::unique_ptr<OptimizedNetwork> net,
         }
     }
 
+    ProfilingGuid networkGuid = m_OptimizedNetwork->GetGuid();
+    std::unique_ptr<TimelineUtilityMethods> timelineUtils =
+                        TimelineUtilityMethods::GetTimelineUtils(m_ProfilingService);
+    if (timelineUtils)
+    {
+        timelineUtils->CreateTypedEntity(networkGuid, LabelsAndEventClasses::NETWORK_GUID);
+        // Mark the network with a start of life event
+        timelineUtils->RecordEvent(networkGuid, LabelsAndEventClasses::ARMNN_PROFILING_SOL_EVENT_CLASS);
+        // and with the process ID
+        int processID = armnnUtils::Processes::GetCurrentId();
+        std::stringstream ss;
+        ss << processID;
+        timelineUtils->MarkEntityWithLabel(networkGuid, ss.str(), LabelsAndEventClasses::PROCESS_ID_GUID);
+    }
+
     //Then create workloads.
     for (auto&& layer : order)
     {
+        if (timelineUtils)
+        {
+            // Add layer to the post-optimisation network structure
+            AddLayerStructure(timelineUtils, *layer, networkGuid);
+        }
+
         const IWorkloadFactory& workloadFactory = GetWorkloadFactory(*layer);
 
         switch (layer->GetType())
@@ -164,17 +228,24 @@ LoadedNetwork::LoadedNetwork(std::unique_ptr<OptimizedNetwork> net,
             }
         default:
             {
-                auto workload = layer->CreateWorkload(m_OptimizedNetwork->GetGraph(), workloadFactory);
+                auto workload = layer->CreateWorkload(workloadFactory);
 
                 if (!workload)
                 {
-                    const char* const layerName = layer->GetNameStr().length() != 0 ? layer->GetName() : "<Unnamed>";
+                    const char* const layerName =
+                        layer->GetNameStr().length() != 0 ? layer->GetName() : "<Unnamed>";
                     throw InvalidArgumentException(boost::str(
                         boost::format("No workload created for layer (name: '%1%' type: '%2%') (compute '%3%')")
                         % layerName % static_cast<int>(layer->GetType()) % layer->GetBackendId().Get()
                     ));
                 }
 
+                if (timelineUtils)
+                {
+                    // Add workload to the post-optimisation network structure
+                    AddWorkloadStructure(timelineUtils, workload, *layer);
+                }
+
                 m_WorkloadQueue.push_back(move(workload));
                 // release the constant data in the layer..
                 layer->ReleaseConstantData();
@@ -183,6 +254,12 @@ LoadedNetwork::LoadedNetwork(std::unique_ptr<OptimizedNetwork> net,
         }
     }
 
+    if (timelineUtils)
+    {
+        // Commit to send the post-optimisation network structure
+        timelineUtils->Commit();
+    }
+
     // Set up memory.
     m_OptimizedNetwork->GetGraph().AllocateDynamicBuffers();
 
@@ -193,11 +270,53 @@ LoadedNetwork::LoadedNetwork(std::unique_ptr<OptimizedNetwork> net,
     }
 }
 
+void LoadedNetwork::SendNetworkStructure()
+{
+    Graph& order = m_OptimizedNetwork->GetGraph().TopologicalSort();
+    ProfilingGuid networkGuid = m_OptimizedNetwork->GetGuid();
+
+    std::unique_ptr<TimelineUtilityMethods> timelineUtils =
+                        TimelineUtilityMethods::GetTimelineUtils(m_ProfilingService);
+
+    timelineUtils->CreateTypedEntity(networkGuid, LabelsAndEventClasses::NETWORK_GUID);
+
+    for (auto&& layer : order)
+    {
+        // Add layer to the post-optimisation network structure
+        AddLayerStructure(timelineUtils, *layer, networkGuid);
+        switch (layer->GetType())
+        {
+        case LayerType::Input:
+        case LayerType::Output:
+        {
+            // Inputs and outputs are treated in a special way - see EnqueueInput() and EnqueueOutput().
+            break;
+        }
+        default:
+            {
+            for (auto& workload : m_WorkloadQueue)
+            {
+                // Add workload to the post-optimisation network structure
+                AddWorkloadStructure(timelineUtils, workload, *layer);
+            }
+            break;
+            }
+        }
+    }
+    // Commit to send the post-optimisation network structure
+    timelineUtils->Commit();
+}
+
+profiling::ProfilingGuid LoadedNetwork::GetNetworkGuid()
+{
+    return m_OptimizedNetwork->GetGuid();
+}
+
 TensorInfo LoadedNetwork::GetInputTensorInfo(LayerBindingId layerId) const
 {
     for (auto&& inputLayer : m_OptimizedNetwork->GetGraph().GetInputLayers())
     {
-        BOOST_ASSERT_MSG(inputLayer->GetNumOutputSlots() == 1, "Input layer should have exactly 1 output slot");
+        ARMNN_ASSERT_MSG(inputLayer->GetNumOutputSlots() == 1, "Input layer should have exactly 1 output slot");
         if (inputLayer->GetBindingId() == layerId)
         {
             return inputLayer->GetOutputSlot(0).GetTensorInfo();
@@ -211,8 +330,8 @@ TensorInfo LoadedNetwork::GetOutputTensorInfo(LayerBindingId layerId) const
 {
     for (auto&& outputLayer : m_OptimizedNetwork->GetGraph().GetOutputLayers())
     {
-        BOOST_ASSERT_MSG(outputLayer->GetNumInputSlots() == 1, "Output layer should have exactly 1 input slot");
-        BOOST_ASSERT_MSG(outputLayer->GetInputSlot(0).GetConnection(), "Input slot on Output layer must be connected");
+        ARMNN_ASSERT_MSG(outputLayer->GetNumInputSlots() == 1, "Output layer should have exactly 1 input slot");
+        ARMNN_ASSERT_MSG(outputLayer->GetInputSlot(0).GetConnection(), "Input slot on Output layer must be connected");
         if (outputLayer->GetBindingId() == layerId)
         {
             return outputLayer->GetInputSlot(0).GetConnection()->GetTensorInfo();
@@ -239,12 +358,12 @@ const IWorkloadFactory& LoadedNetwork::GetWorkloadFactory(const Layer& layer) co
 
     workloadFactory = it->second.first.get();
 
-    BOOST_ASSERT_MSG(workloadFactory, "No workload factory");
+    ARMNN_ASSERT_MSG(workloadFactory, "No workload factory");
 
     std::string reasonIfUnsupported;
-    BOOST_ASSERT_MSG(IWorkloadFactory::IsLayerSupported(layer, {}, reasonIfUnsupported),
+    ARMNN_ASSERT_MSG(IWorkloadFactory::IsLayerSupported(layer, {}, reasonIfUnsupported),
         "Factory does not support layer");
-    boost::ignore_unused(reasonIfUnsupported);
+    IgnoreUnused(reasonIfUnsupported);
     return *workloadFactory;
 }
 
@@ -345,14 +464,12 @@ private:
 Status LoadedNetwork::EnqueueWorkload(const InputTensors& inputTensors,
                                       const OutputTensors& outputTensors)
 {
-    ARMNN_SCOPED_PROFILING_EVENT(Compute::Undefined, "EnqueueWorkload");
-
     const Graph& graph = m_OptimizedNetwork->GetGraph();
 
     // Walk graph to determine the order of execution.
     if (graph.GetNumLayers() < 2)
     {
-        BOOST_LOG_TRIVIAL(warning) << "IRuntime::EnqueueWorkload()::Less than two nodes in graph";
+        ARMNN_LOG(warning) << "IRuntime::EnqueueWorkload()::Less than two nodes in graph";
         return Status::Failure;
     }
 
@@ -365,31 +482,62 @@ Status LoadedNetwork::EnqueueWorkload(const InputTensors& inputTensors,
     }
 
     // For each input to the network, call EnqueueInput with the data passed by the user.
-    m_InputQueue.clear();
-    m_InputQueue.reserve(graph.GetNumInputs());
-    for (const BindableLayer* inputLayer : graph.GetInputLayers())
     {
-        const TensorPin& pin = workloadData.GetInputTensorPin(inputLayer->GetBindingId());
-        EnqueueInput(*inputLayer, pin.GetTensorHandle(), pin.GetTensorInfo());
+        ARMNN_SCOPED_PROFILING_EVENT(Compute::Undefined, "PrepareInputs");
+        m_InputQueue.clear();
+        m_InputQueue.reserve(graph.GetNumInputs());
+        for (const BindableLayer* inputLayer : graph.GetInputLayers())
+        {
+            const TensorPin& pin = workloadData.GetInputTensorPin(inputLayer->GetBindingId());
+            EnqueueInput(*inputLayer, pin.GetTensorHandle(), pin.GetTensorInfo());
+        }
     }
 
     // For each output to the network, call EnqueueOutput with the data passed by the user.
-    m_OutputQueue.clear();
-    m_OutputQueue.reserve(graph.GetNumOutputs());
-    for (const BindableLayer* outputLayer : graph.GetOutputLayers())
     {
-        const TensorPin& pin = workloadData.GetOutputTensorPin(outputLayer->GetBindingId());
-        EnqueueOutput(*outputLayer, pin.GetTensorHandle(), pin.GetTensorInfo());
+        ARMNN_SCOPED_PROFILING_EVENT(Compute::Undefined, "PrepareOutputs");
+        m_OutputQueue.clear();
+        m_OutputQueue.reserve(graph.GetNumOutputs());
+        for (const BindableLayer* outputLayer : graph.GetOutputLayers())
+        {
+            const TensorPin& pin = workloadData.GetOutputTensorPin(outputLayer->GetBindingId());
+            EnqueueOutput(*outputLayer, pin.GetTensorHandle(), pin.GetTensorInfo());
+        }
+    }
+
+    std::unique_ptr<TimelineUtilityMethods> timelineUtils =
+                        TimelineUtilityMethods::GetTimelineUtils(m_ProfilingService);
+    ProfilingGuid inferenceGuid = m_ProfilingService.GetNextGuid();
+    if (timelineUtils)
+    {
+        // Add inference timeline trace if profiling is enabled.
+        ProfilingGuid networkGuid = m_OptimizedNetwork->GetGuid();
+        timelineUtils->CreateTypedEntity(inferenceGuid, LabelsAndEventClasses::INFERENCE_GUID);
+        timelineUtils->CreateRelationship(ProfilingRelationshipType::RetentionLink,
+                                          networkGuid,
+                                          inferenceGuid,
+                                          LabelsAndEventClasses::EXECUTION_OF_GUID);
+        timelineUtils->RecordEvent(inferenceGuid, LabelsAndEventClasses::ARMNN_PROFILING_SOL_EVENT_CLASS);
     }
 
     bool executionSucceeded = true;
 
     {
+        if (m_ProfilingService.IsProfilingEnabled())
+        {
+            m_ProfilingService.IncrementCounterValue(armnn::profiling::INFERENCES_RUN);
+        }
         ARMNN_SCOPED_PROFILING_EVENT(Compute::Undefined, "Execute");
         ARMNN_SCOPED_HEAP_PROFILING("Executing");
-        executionSucceeded = Execute();
+        executionSucceeded = Execute(timelineUtils, inferenceGuid);
     }
 
+    if (timelineUtils)
+    {
+        // Add end of life of the inference timeline if profiling is enabled.
+        timelineUtils->RecordEvent(inferenceGuid, LabelsAndEventClasses::ARMNN_PROFILING_EOL_EVENT_CLASS);
+        timelineUtils->Commit();
+    }
     return executionSucceeded ? Status::Success : Status::Failure;
 }
 
@@ -411,11 +559,11 @@ void LoadedNetwork::EnqueueInput(const BindableLayer& layer, ITensorHandle* tens
     inputQueueDescriptor.m_Inputs.push_back(tensorHandle);
     info.m_InputTensorInfos.push_back(tensorInfo);
 
-    BOOST_ASSERT_MSG(layer.GetNumOutputSlots() == 1, "Can only handle Input Layer with one output");
+    ARMNN_ASSERT_MSG(layer.GetNumOutputSlots() == 1, "Can only handle Input Layer with one output");
     const OutputHandler& handler = layer.GetOutputHandler();
     const TensorInfo& outputTensorInfo = handler.GetTensorInfo();
     ITensorHandle* outputTensorHandle = handler.GetData();
-    BOOST_ASSERT_MSG(outputTensorHandle != nullptr,
+    ARMNN_ASSERT_MSG(outputTensorHandle != nullptr,
                      "Data should have been allocated.");
     inputQueueDescriptor.m_Outputs.push_back(outputTensorHandle);
     info.m_OutputTensorInfos.push_back(outputTensorInfo);
@@ -443,9 +591,19 @@ void LoadedNetwork::EnqueueInput(const BindableLayer& layer, ITensorHandle* tens
     else
     {
         // Create a mem copy workload for input since we did not import
-        auto inputWorkload = std::make_unique<CopyMemGenericWorkload>(inputQueueDescriptor, info);
+        std::unique_ptr<IWorkload> inputWorkload = std::make_unique<CopyMemGenericWorkload>(inputQueueDescriptor, info);
+
+        ARMNN_ASSERT_MSG(inputWorkload, "No input workload created");
+
+        std::unique_ptr<TimelineUtilityMethods> timelineUtils =
+                            TimelineUtilityMethods::GetTimelineUtils(m_ProfilingService);
+        if (timelineUtils)
+        {
+            // Add Input Workload to the post-optimisation network structure
+            AddWorkloadStructure(timelineUtils, inputWorkload, layer);
+            timelineUtils->Commit();
+        }
 
-        BOOST_ASSERT_MSG(inputWorkload, "No input workload created");
         m_InputQueue.push_back(move(inputWorkload));
     }
 }
@@ -468,14 +626,14 @@ void LoadedNetwork::EnqueueOutput(const BindableLayer& layer, ITensorHandle* ten
     outputQueueDescriptor.m_Outputs.push_back(tensorHandle);
     info.m_OutputTensorInfos.push_back(tensorInfo);
 
-    BOOST_ASSERT_MSG(layer.GetNumInputSlots() == 1, "Output Layer should have exactly one input.");
+    ARMNN_ASSERT_MSG(layer.GetNumInputSlots() == 1, "Output Layer should have exactly one input.");
 
     // Gets the output handler from the previous node.
     const OutputHandler& outputHandler = layer.GetInputSlots()[0].GetConnectedOutputSlot()->GetOutputHandler();
 
     const TensorInfo& inputTensorInfo = outputHandler.GetTensorInfo();
     ITensorHandle* inputTensorHandle = outputHandler.GetData();
-    BOOST_ASSERT_MSG(inputTensorHandle != nullptr, "Data should have been allocated.");
+    ARMNN_ASSERT_MSG(inputTensorHandle != nullptr, "Data should have been allocated.");
 
     // Try import the output tensor.
     // Note: We can only import the output pointer if all of the following  hold true:
@@ -502,7 +660,7 @@ void LoadedNetwork::EnqueueOutput(const BindableLayer& layer, ITensorHandle* ten
                     syncDesc.m_Inputs.push_back(inputTensorHandle);
                     info.m_InputTensorInfos.push_back(inputTensorInfo);
                     auto syncWorkload = std::make_unique<SyncMemGenericWorkload>(syncDesc, info);
-                    BOOST_ASSERT_MSG(syncWorkload, "No sync workload created");
+                    ARMNN_ASSERT_MSG(syncWorkload, "No sync workload created");
                     m_OutputQueue.push_back(move(syncWorkload));
                 }
                 else
@@ -526,14 +684,30 @@ void LoadedNetwork::EnqueueOutput(const BindableLayer& layer, ITensorHandle* ten
         outputQueueDescriptor.m_Inputs.push_back(inputTensorHandle);
         info.m_InputTensorInfos.push_back(inputTensorInfo);
 
-        auto outputWorkload = std::make_unique<CopyMemGenericWorkload>(outputQueueDescriptor, info);
-        BOOST_ASSERT_MSG(outputWorkload, "No output workload created");
+        std::unique_ptr<IWorkload> outputWorkload =
+            std::make_unique<CopyMemGenericWorkload>(outputQueueDescriptor, info);
+        ARMNN_ASSERT_MSG(outputWorkload, "No output workload created");
+
+        std::unique_ptr<TimelineUtilityMethods> timelineUtils =
+                                TimelineUtilityMethods::GetTimelineUtils(m_ProfilingService);
+        if (timelineUtils)
+        {
+            // Add Output Workload to the post-optimisation network structure
+            AddWorkloadStructure(timelineUtils, outputWorkload, layer);
+            timelineUtils->Commit();
+        }
+
         m_OutputQueue.push_back(move(outputWorkload));
     }
 }
 
-void LoadedNetwork::AllocateWorkingMemory()
+void LoadedNetwork::AllocateWorkingMemory(std::lock_guard<std::mutex>& lock)
 {
+    ARMNN_SCOPED_PROFILING_EVENT(Compute::Undefined, "Working Memory Allocation");
+
+    // this unused parameter makes sure we can only call this function with a valid lock
+    IgnoreUnused(lock);
+
     if (m_IsWorkingMemAllocated)
     {
         return;
@@ -570,35 +744,43 @@ void LoadedNetwork::FreeWorkingMemory()
     m_IsWorkingMemAllocated = false;
 }
 
-bool LoadedNetwork::Execute()
+bool LoadedNetwork::Execute(std::unique_ptr<TimelineUtilityMethods>& timelineUtils,
+                            profiling::ProfilingGuid inferenceGuid)
 {
     bool success = true;
 
     auto Fail = [&](const std::exception& error)
     {
-        BOOST_LOG_TRIVIAL(error) << "An error occurred attempting to execute a workload: " << error.what();
+        ARMNN_LOG(error) << "An error occurred attempting to execute a workload: " << error.what();
         success = false;
     };
 
     try
     {
         std::lock_guard<std::mutex> lockGuard(m_WorkingMemMutex);
-        AllocateWorkingMemory();
+        AllocateWorkingMemory(lockGuard);
 
-        for (auto& input : m_InputQueue)
+        ProfilingDynamicGuid workloadInferenceID(0);
+        auto ExecuteQueue = [&timelineUtils, &workloadInferenceID, &inferenceGuid](WorkloadQueue& queue)
         {
-            input->Execute();
-        }
+            for (auto& workload : queue)
+            {
+                if(timelineUtils)
+                {
+                    workloadInferenceID = timelineUtils->RecordWorkloadInferenceAndStartOfLifeEvent(workload->GetGuid(),
+                                                                                                    inferenceGuid);
+                }
+                workload->Execute();
+                if(timelineUtils)
+                {
+                    timelineUtils->RecordEndOfLifeEvent(workloadInferenceID);
+                }
+            }
+        };
 
-        for (auto& workload : m_WorkloadQueue)
-        {
-            workload->Execute();
-        }
-
-        for (auto& output: m_OutputQueue)
-        {
-            output->Execute();
-        }
+        ExecuteQueue(m_InputQueue);
+        ExecuteQueue(m_WorkloadQueue);
+        ExecuteQueue(m_OutputQueue);
     }
     catch (const RuntimeException& error)
     {
