@@ -10,20 +10,19 @@
 #include <armnn/Tensor.hpp>
 #include <armnn/TypesUtils.hpp>
 #include <armnn/ILayerVisitor.hpp>
+#include <armnn/utility/Assert.hpp>
 
 #include <utility>
 #include <limits>
 
-#include <boost/assert.hpp>
-
 namespace armnn
 {
 
 template<typename srcType>
 void QuantizeConstant(const srcType* src, uint8_t* dst, size_t numElements, float& scale, int& offset)
 {
-    BOOST_ASSERT(src);
-    BOOST_ASSERT(dst);
+    ARMNN_ASSERT(src);
+    ARMNN_ASSERT(dst);
 
     float min = std::numeric_limits<srcType>::max();
     float max = std::numeric_limits<srcType>::lowest();
@@ -33,7 +32,7 @@ void QuantizeConstant(const srcType* src, uint8_t* dst, size_t numElements, floa
         max = std::max(max, src[i]);
     }
 
-    QAsymm8QuantizationScheme quantizationScheme;
+    QAsymmU8QuantizationScheme quantizationScheme;
     OffsetScalePair qParams = quantizationScheme.ComputeScheme(min, max);
     scale = qParams.first;
     offset = qParams.second;
