@@ -6,6 +6,7 @@
 #pragma once
 
 #include "armnn/Types.hpp"
+#include "BFloat16.hpp"
 #include "Half.hpp"
 
 namespace armnn
@@ -27,13 +28,25 @@ struct ResolveTypeImpl<DataType::Float32>
 };
 
 template<>
-struct ResolveTypeImpl<DataType::QuantisedAsymm8>
+struct ResolveTypeImpl<DataType::QAsymmU8>
 {
     using Type = uint8_t;
 };
 
 template<>
-struct ResolveTypeImpl<DataType::QuantisedSymm16>
+struct ResolveTypeImpl<DataType::QAsymmS8>
+{
+    using Type = int8_t;
+};
+
+template<>
+struct ResolveTypeImpl<DataType::QSymmS8>
+{
+    using Type = int8_t;
+};
+
+template<>
+struct ResolveTypeImpl<DataType::QSymmS16>
 {
     using Type = int16_t;
 };
@@ -50,6 +63,12 @@ struct ResolveTypeImpl<DataType::Boolean>
     using Type = uint8_t;
 };
 
+template<>
+struct ResolveTypeImpl<DataType::BFloat16>
+{
+    using Type = BFloat16;
+};
+
 template<DataType DT>
 using ResolveType = typename ResolveTypeImpl<DT>::Type;
 
