@@ -5,7 +5,11 @@
 
 #include "SubgraphViewSelector.hpp"
 #include "Graph.hpp"
-#include <boost/assert.hpp>
+
+#include <armnn/utility/Assert.hpp>
+#include <armnn/utility/IgnoreUnused.hpp>
+#include <armnn/utility/PolymorphicDowncast.hpp>
+
 #include <algorithm>
 #include <map>
 #include <queue>
@@ -77,15 +81,15 @@ public:
             for (PartialSubgraph* a : m_Antecedents)
             {
                 size_t numErased = a->m_Dependants.erase(this);
-                BOOST_ASSERT(numErased == 1);
-                boost::ignore_unused(numErased);
+                ARMNN_ASSERT(numErased == 1);
+                IgnoreUnused(numErased);
                 a->m_Dependants.insert(m_Parent);
             }
             for (PartialSubgraph* a : m_Dependants)
             {
                 size_t numErased = a->m_Antecedents.erase(this);
-                BOOST_ASSERT(numErased == 1);
-                boost::ignore_unused(numErased);
+                ARMNN_ASSERT(numErased == 1);
+                IgnoreUnused(numErased);
                 a->m_Antecedents.insert(m_Parent);
             }
 
@@ -194,7 +198,7 @@ struct LayerSelectionInfo
         for (auto&& slot = m_Layer->BeginInputSlots(); slot != m_Layer->EndInputSlots(); ++slot)
         {
             OutputSlot* parentLayerOutputSlot = slot->GetConnectedOutputSlot();
-            BOOST_ASSERT_MSG(parentLayerOutputSlot != nullptr, "The input slots must be connected here.");
+            ARMNN_ASSERT_MSG(parentLayerOutputSlot != nullptr, "The input slots must be connected here.");
             if (parentLayerOutputSlot)
             {
                 Layer& parentLayer = parentLayerOutputSlot->GetOwningLayer();
@@ -264,8 +268,8 @@ void ForEachLayerInput(LayerSelectionInfo::LayerInfoContainer& layerInfos,
 
     for (auto inputSlot : layer.GetInputSlots())
     {
-        auto connectedInput = boost::polymorphic_downcast<OutputSlot*>(inputSlot.GetConnection());
-        BOOST_ASSERT_MSG(connectedInput, "Dangling input slot detected.");
+        auto connectedInput = PolymorphicDowncast<OutputSlot*>(inputSlot.GetConnection());
+        ARMNN_ASSERT_MSG(connectedInput, "Dangling input slot detected.");
         Layer& inputLayer = connectedInput->GetOwningLayer();
 
         auto parentInfo = layerInfos.find(&inputLayer);
