@@ -1,5 +1,5 @@
 //
-// Copyright © 2019 Arm Ltd. All rights reserved.
+// Copyright © 2019 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -14,8 +14,9 @@ StandInLayer::StandInLayer(const StandInDescriptor& param, const char* name)
 {
 }
 
-std::unique_ptr<IWorkload> StandInLayer::CreateWorkload(const Graph& graph, const IWorkloadFactory& factory) const
+std::unique_ptr<IWorkload> StandInLayer::CreateWorkload(const IWorkloadFactory& factory) const
 {
+    IgnoreUnused(factory);
     // This throws in the event that it's called. We would expect that any backend that
     // "claims" to support the StandInLayer type would actually substitute it with a PrecompiledLayer
     // during graph optimization. There is no interface on the IWorkloadFactory to create a StandInWorkload.
@@ -29,11 +30,13 @@ StandInLayer* StandInLayer::Clone(Graph& graph) const
 
 std::vector<TensorShape> StandInLayer::InferOutputShapes(const std::vector<TensorShape>& inputShapes) const
 {
+    IgnoreUnused(inputShapes);
     throw Exception("Stand in layer does not support infering output shapes");
 }
 
 void StandInLayer::ValidateTensorShapesFromInputs()
 {
+
     // Cannot validate this layer since no implementation details can be known by the framework
     // so do nothing here.
 }
