@@ -1,35 +1,23 @@
-﻿//
+//
 // Copyright © 2017 Arm Ltd. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #include "GraphUtils.hpp"
 
-#include <boost/test/unit_test.hpp>
-#include <boost/cast.hpp>
-
-#include <armnn/ArmNN.hpp>
-#include <armnn/TypesUtils.hpp>
-#include <armnn/Exceptions.hpp>
 #include <Graph.hpp>
 #include <Layer.hpp>
 
+#include <armnn/TypesUtils.hpp>
+#include <armnn/Exceptions.hpp>
+#include <armnn/utility/PolymorphicDowncast.hpp>
+
+#include <armnn/backends/IBackendInternal.hpp>
+
 #include <backendsCommon/CpuTensorHandle.hpp>
-#include <backendsCommon/IBackendInternal.hpp>
 #include <backendsCommon/TensorHandleFactoryRegistry.hpp>
 
-
-/// Checks that first comes before second in the order.
-bool CheckOrder(const armnn::Graph& graph, const armnn::Layer* first, const armnn::Layer* second)
-{
-    graph.Print();
-
-    const auto& order = graph.TopologicalSort();
-
-    auto firstPos = std::find(order.begin(), order.end(), first);
-    auto secondPos = std::find(firstPos, order.end(), second);
-
-    return (secondPos != order.end());
-}
+#include <boost/cast.hpp>
+#include <boost/test/unit_test.hpp>
 
 BOOST_AUTO_TEST_SUITE(Graph)
 
@@ -274,7 +262,7 @@ static std::vector<Edge> GetEdgeList(const armnn::Graph& graph)
             const unsigned int numConnections = outputSlot.GetNumConnections();
             for (unsigned int c = 0; c < numConnections; ++c)
             {
-                auto inputSlot = boost::polymorphic_downcast<const armnn::InputSlot*>(outputSlot.GetConnection(c));
+                auto inputSlot = armnn::PolymorphicDowncast<const armnn::InputSlot*>(outputSlot.GetConnection(c));
                 edges.emplace_back(srcLayer, &inputSlot->GetOwningLayer());
             }
         }
