@@ -1,15 +1,25 @@
-﻿//
-// Copyright © 2017 Arm Ltd. All rights reserved.
+//
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #include "TestUtils.hpp"
 
-#include <armnn/ArmNN.hpp>
+#include <BackendSettings.hpp>
 #include <Graph.hpp>
+#include <Network.hpp>
 #include <Optimizer.hpp>
+
+#include <armnn/BackendRegistry.hpp>
+#include <armnn/INetwork.hpp>
+#include <armnn/LayerVisitorBase.hpp>
+
+#include <armnnUtils/FloatingPointConverter.hpp>
+#include <armnn/utility/PolymorphicDowncast.hpp>
+
 #include <backendsCommon/CpuTensorHandle.hpp>
-#include <FloatingPointConverter.hpp>
+#include <backendsCommon/IBackendInternal.hpp>
+#include <backendsCommon/LayerSupportBase.hpp>
 
 #include <boost/test/unit_test.hpp>
 
@@ -69,13 +79,10 @@ void CreateLSTMLayerHelper(Graph &graph, bool CifgEnabled)
                 (TensorInfo({ numUnits, inputSize }, DataType::Float32));
         layer->m_CifgParameters.m_RecurrentToInputWeights = std::make_unique<ScopedCpuTensorHandle>
                 (TensorInfo({ numUnits, outputSize }, DataType::Float32));
-        layer->m_CifgParameters.m_CellToInputWeights = std::make_unique<ScopedCpuTensorHandle>
-                (TensorInfo({ numUnits }, DataType::Float32));
         layer->m_CifgParameters.m_InputGateBias = std::make_unique<ScopedCpuTensorHandle>
                 (TensorInfo({ numUnits }, DataType::Float32));
         layer->m_CifgParameters.m_InputToInputWeights->Allocate();
         layer->m_CifgParameters.m_RecurrentToInputWeights->Allocate();
-        layer->m_CifgParameters.m_CellToInputWeights->Allocate();
         layer->m_CifgParameters.m_InputGateBias->Allocate();
     }
 
@@ -91,6 +98,12 @@ void CreateLSTMLayerHelper(Graph &graph, bool CifgEnabled)
 
     if (layerDesc.m_PeepholeEnabled)
     {
+        if (!layerDesc.m_CifgEnabled)
+        {
+            layer->m_PeepholeParameters.m_CellToInputWeights = std::make_unique<ScopedCpuTensorHandle>
+                    (TensorInfo({ numUnits }, DataType::Float32));
+            layer->m_PeepholeParameters.m_CellToInputWeights->Allocate();
+        }
         layer->m_PeepholeParameters.m_CellToForgetWeights = std::make_unique<ScopedCpuTensorHandle>
                 (TensorInfo({ numUnits }, DataType::Float32));
         layer->m_PeepholeParameters.m_CellToOutputWeights = std::make_unique<ScopedCpuTensorHandle>
@@ -191,8 +204,8 @@ BOOST_AUTO_TEST_CASE(InsertConvertersTest)
     {
         if(layer->GetType()==LayerType::Floor || layer->GetType() == LayerType::Addition)
         {
-            BOOST_ASSERT(layer->GetOutputSlot(0).GetTensorInfo().GetDataType() == DataType::Float16);
-            BOOST_ASSERT(layer->GetDataType() == DataType::Float16);
+            ARMNN_ASSERT(layer->GetOutputSlot(0).GetTensorInfo().GetDataType() == DataType::Float16);
+            ARMNN_ASSERT(layer->GetDataType() == DataType::Float16);
         }
     }
 
@@ -211,18 +224,18 @@ BOOST_AUTO_TEST_CASE(InsertConvertersTest)
     {
         if (layer->GetType()==LayerType::Floor || layer->GetType() == LayerType::Addition)
         {
-            BOOST_ASSERT(layer->GetOutputSlot(0).GetTensorInfo().GetDataType() == DataType::Float32);
-            BOOST_ASSERT(layer->GetDataType() == DataType::Float32);
+            ARMNN_ASSERT(layer->GetOutputSlot(0).GetTensorInfo().GetDataType() == DataType::Float32);
+            ARMNN_ASSERT(layer->GetDataType() == DataType::Float32);
         }
         else if (layer->GetType() == LayerType::ConvertFp16ToFp32)
         {
-            BOOST_ASSERT(layer->GetOutputSlot(0).GetTensorInfo().GetDataType() == DataType::Float32);
-            BOOST_ASSERT(layer->GetDataType() == DataType::Float16);
+            ARMNN_ASSERT(layer->GetOutputSlot(0).GetTensorInfo().GetDataType() == DataType::Float32);
+            ARMNN_ASSERT(layer->GetDataType() == DataType::Float16);
         }
         else if (layer->GetType() == LayerType::ConvertFp32ToFp16)
         {
-            BOOST_ASSERT(layer->GetOutputSlot(0).GetTensorInfo().GetDataType() == DataType::Float16);
-            BOOST_ASSERT(layer->GetDataType() == DataType::Float32);
+            ARMNN_ASSERT(layer->GetOutputSlot(0).GetTensorInfo().GetDataType() == DataType::Float16);
+            ARMNN_ASSERT(layer->GetDataType() == DataType::Float32);
         }
     }
 
@@ -445,7 +458,8 @@ void CreateGatherGraph(Graph& graph, const armnn::TensorInfo& paramsInfo, const
     Layer* input1 = graph.AddLayer<InputLayer>(1, "indices");
     input1->GetOutputSlot().SetTensorInfo(indicesInfo);
 
-    GatherLayer* layer = graph.AddLayer<GatherLayer>("gather");
+    GatherDescriptor descriptor;
+    GatherLayer* layer = graph.AddLayer<GatherLayer>(descriptor, "gather");
     layer->GetOutputSlot().SetTensorInfo(outputInfo);
 
     Layer* output = graph.AddLayer<OutputLayer>(0, "output");
@@ -493,15 +507,15 @@ BOOST_AUTO_TEST_CASE(GatherValidateTensorShapesFromInputsMultiDimIndices)
 BOOST_AUTO_TEST_CASE(DetectionPostProcessValidateTensorShapes)
 {
     Graph graph;
-    armnn::TensorInfo boxEncodingsInfo({1, 10, 4}, DataType::QuantisedAsymm8);
-    armnn::TensorInfo scoresInfo({1, 10, 4}, DataType::QuantisedAsymm8);
+    armnn::TensorInfo boxEncodingsInfo({1, 10, 4}, DataType::QAsymmU8);
+    armnn::TensorInfo scoresInfo({1, 10, 4}, DataType::QAsymmU8);
     std::vector<uint8_t> anchorsVector(40);
-    armnn::ConstTensor anchors(armnn::TensorInfo({10, 4}, armnn::DataType::QuantisedAsymm8), anchorsVector);
+    armnn::ConstTensor anchors(armnn::TensorInfo({10, 4}, armnn::DataType::QAsymmU8), anchorsVector);
 
-    armnn::TensorInfo detectionBoxesInfo({1, 3, 4}, DataType::QuantisedAsymm8);
-    armnn::TensorInfo detectionScoresInfo({1, 3}, DataType::QuantisedAsymm8);
-    armnn::TensorInfo detectionClassesInfo({1, 3}, DataType::QuantisedAsymm8);
-    armnn::TensorInfo numDetectionInfo({1}, DataType::QuantisedAsymm8);
+    armnn::TensorInfo detectionBoxesInfo({1, 3, 4}, DataType::QAsymmU8);
+    armnn::TensorInfo detectionScoresInfo({1, 3}, DataType::QAsymmU8);
+    armnn::TensorInfo detectionClassesInfo({1, 3}, DataType::QAsymmU8);
+    armnn::TensorInfo numDetectionInfo({1}, DataType::QAsymmU8);
 
     Layer* input0 = graph.AddLayer<InputLayer>(0, "boxEncodings");
     input0->GetOutputSlot().SetTensorInfo(boxEncodingsInfo);
@@ -614,4 +628,174 @@ BOOST_AUTO_TEST_CASE(FoldPadLayerIntoConvolution2dLayer)
         &IsLayerOfType<armnn::OutputLayer>));
 }
 
+
+
+
+class MockLayerSupport : public LayerSupportBase {
+public:
+    bool IsInputSupported(const TensorInfo& /*input*/,
+                          Optional<std::string&> /*reasonIfUnsupported = EmptyOptional()*/) const override
+    {
+        return true;
+    }
+
+    bool IsOutputSupported(const TensorInfo& /*input*/,
+                           Optional<std::string&> /*reasonIfUnsupported = EmptyOptional()*/) const override
+    {
+        return true;
+    }
+
+    bool IsActivationSupported(const TensorInfo& /*input0*/,
+                               const TensorInfo& /*output*/,
+                               const ActivationDescriptor& /*descriptor*/,
+                               Optional<std::string&> /*reasonIfUnsupported = EmptyOptional()*/) const override
+    {
+        return true;
+    }
+};
+
+template<typename NamePolicy>
+class MockBackend : public IBackendInternal
+{
+public:
+    MockBackend()  = default;
+    ~MockBackend() = default;
+
+    static const BackendId& GetIdStatic() { return NamePolicy::GetIdStatic(); }
+    const BackendId& GetId() const override { return GetIdStatic(); }
+
+    IBackendInternal::IMemoryManagerUniquePtr CreateMemoryManager() const override { return nullptr; };
+
+    IBackendInternal::IWorkloadFactoryPtr CreateWorkloadFactory(
+        const IBackendInternal::IMemoryManagerSharedPtr&) const override { return nullptr; }
+
+    IBackendInternal::IBackendContextPtr CreateBackendContext(const IRuntime::CreationOptions&) const override
+    {
+        return nullptr;
+    }
+
+    IBackendInternal::Optimizations GetOptimizations() const override { return {}; }
+    IBackendInternal::ILayerSupportSharedPtr GetLayerSupport() const override
+    {
+        return std::make_shared<MockLayerSupport>();
+    }
+
+    OptimizationViews OptimizeSubgraphView(const SubgraphView&) const override
+    {
+        return {};
+    };
+};
+
+
+BOOST_AUTO_TEST_CASE(BackendHintTest)
+{
+    class TestBackendAssignment : public LayerVisitorBase<VisitorNoThrowPolicy>
+    {
+    public:
+        void VisitInputLayer(const IConnectableLayer* layer,
+                             LayerBindingId id,
+                             const char* name = nullptr) override
+        {
+            IgnoreUnused(id, name);
+            auto inputLayer = PolymorphicDowncast<const InputLayer*>(layer);
+            BOOST_TEST((inputLayer->GetBackendId() == "MockBackend"));
+        }
+
+        void VisitOutputLayer(const IConnectableLayer* layer,
+                              LayerBindingId id,
+                              const char* name = nullptr) override
+        {
+            IgnoreUnused(id, name);
+            auto outputLayer = PolymorphicDowncast<const OutputLayer*>(layer);
+            BOOST_TEST((outputLayer->GetBackendId() == "MockBackend"));
+        }
+
+        void VisitActivationLayer(const IConnectableLayer* layer,
+                                  const ActivationDescriptor& activationDescriptor,
+                                  const char* name = nullptr) override
+        {
+            IgnoreUnused(activationDescriptor, name);
+            auto activation = PolymorphicDowncast<const ActivationLayer*>(layer);
+            BOOST_TEST((activation->GetBackendId() == "CustomBackend"));
+        }
+    };
+
+    struct CustomPolicy
+    {
+        static const BackendId& GetIdStatic()
+        {
+            static BackendId id="CustomBackend";
+            return id;
+        }
+    };
+
+    struct MockPolicy
+    {
+        static const BackendId& GetIdStatic()
+        {
+            static BackendId id="MockBackend";
+            return id;
+        }
+    };
+
+    auto& backendRegistry = BackendRegistryInstance();
+
+    backendRegistry.Register("MockBackend", [](){
+            return std::make_unique<MockBackend<MockPolicy>>();
+        });
+
+    backendRegistry.Register("CustomBackend", [](){
+            return std::make_unique<MockBackend<CustomPolicy>>();
+        });
+
+    // Define the network
+    auto network = INetwork::Create();
+    ActivationDescriptor desc;
+    desc.m_Function = ActivationFunction::Linear;
+
+    std::unique_ptr<Graph> graph = std::make_unique<Graph>();
+    auto input = graph->AddLayer<InputLayer>(0, "input");
+    auto act = graph->AddLayer<ActivationLayer>(desc, "activation");
+    auto output = graph->AddLayer<OutputLayer>(0, "output");
+
+    BackendId customBackendId("CustomBackend");
+    act->BackendSelectionHint(customBackendId);
+
+    input->GetOutputSlot(0).Connect(act->GetInputSlot(0));
+    act->GetOutputSlot(0).Connect(output->GetInputSlot(0));
+
+
+    auto optNet = IOptimizedNetworkPtr(new OptimizedNetwork(std::move(graph)), &IOptimizedNetwork::Destroy);
+
+    OptimizedNetwork* optNetObjPtr = PolymorphicDowncast<OptimizedNetwork*>(optNet.get());
+
+    // Get the optimized graph
+    Graph& optGraph = optNetObjPtr->GetGraph();
+
+
+    std::vector<BackendId> prefs{"MockBackend", "CustomBackend"};
+
+    BackendIdSet availableBackends = {"CustomBackend", "MockBackend"};
+    DeviceSpec spec(availableBackends);
+
+    BackendSettings backendSettings(prefs, spec);
+
+    // Assign an available backend to each layer
+    Graph::Iterator firstLayer = optGraph.begin();
+    Graph::Iterator lastLayer  = optGraph.end();
+    OptimizationResult res = AssignBackends(optNetObjPtr,
+                                            backendSettings,
+                                            firstLayer,
+                                            lastLayer,
+                                            EmptyOptional());
+
+    BOOST_TEST(res.IsOk());
+
+    TestBackendAssignment visitor;
+    for (auto it =firstLayer; it != lastLayer; ++it)
+    {
+        (*it)->Accept(visitor);
+    }
+}
+
 BOOST_AUTO_TEST_SUITE_END()
