@@ -4,7 +4,6 @@
 //
 #include <boost/test/unit_test.hpp>
 
-#include <armnn/ArmNN.hpp>
 
 #include <Graph.hpp>
 #include <SubgraphView.hpp>
@@ -535,7 +534,7 @@ BOOST_AUTO_TEST_CASE(DisjointGraphs)
     SubgraphViewSelector::Subgraphs subgraphs =
         SubgraphViewSelector::SelectSubgraphs(graph,
                                               // select the middle layers only
-                                              [](const Layer& l) {
+                                              [](const Layer&) {
                                                   return true;
                                               });
 
