@@ -5,16 +5,26 @@
 
 #include "TestUtils.hpp"
 
-#include <boost/assert.hpp>
+#include <armnn/utility/Assert.hpp>
 
 using namespace armnn;
 
 void Connect(armnn::IConnectableLayer* from, armnn::IConnectableLayer* to, const armnn::TensorInfo& tensorInfo,
              unsigned int fromIndex, unsigned int toIndex)
 {
-    BOOST_ASSERT(from);
-    BOOST_ASSERT(to);
+    ARMNN_ASSERT(from);
+    ARMNN_ASSERT(to);
 
     from->GetOutputSlot(fromIndex).Connect(to->GetInputSlot(toIndex));
     from->GetOutputSlot(fromIndex).SetTensorInfo(tensorInfo);
 }
+
+namespace armnn
+{
+
+profiling::ProfilingService& GetProfilingService(armnn::Runtime* runtime)
+{
+    return runtime->m_ProfilingService;
+}
+
+}
\ No newline at end of file
