@@ -4,8 +4,7 @@
 //
 #pragma once
 
-#include <armnn/ArmNN.hpp>
-
+#include <armnn/Types.hpp>
 #include <ArmnnSchema_generated.h>
 
 namespace armnnSerializer
@@ -19,6 +18,8 @@ armnnSerializer::DataType GetFlatBufferDataType(armnn::DataType dataType);
 
 armnnSerializer::DataLayout GetFlatBufferDataLayout(armnn::DataLayout dataLayout);
 
+armnnSerializer::UnaryOperation GetFlatBufferUnaryOperation(armnn::UnaryOperation unaryOperation);
+
 armnnSerializer::PoolingAlgorithm GetFlatBufferPoolingAlgorithm(armnn::PoolingAlgorithm poolingAlgorithm);
 
 armnnSerializer::OutputShapeRounding GetFlatBufferOutputShapeRounding(
