@@ -3,7 +3,5 @@
 // SPDX-License-Identifier: MIT
 //
 
-extern "C" {
-extern const char tflite_schema_start;
-extern const char tflite_schema_end;
-}
+extern unsigned char g_TfLiteSchemaText[];
+extern unsigned int g_TfLiteSchemaText_len;
