@@ -1,9 +1,10 @@
-﻿//
+//
 // Copyright © 2017 Arm Ltd. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
-#include "DataLayoutIndexed.hpp"
+#include <armnnUtils/DataLayoutIndexed.hpp>
+
 using namespace armnn;
 
 namespace armnnUtils
