@@ -1,13 +1,14 @@
-﻿//
+//
 // Copyright © 2017 Arm Ltd. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #pragma once
 
-#include "CpuTensorHandleFwd.hpp"
 #include "Workload.hpp"
 #include "WorkloadUtils.hpp"
 
+#include <armnn/backends/CpuTensorHandleFwd.hpp>
+
 #include <utility>
 
 namespace armnn
