@@ -1,14 +1,13 @@
-﻿//
+//
 // Copyright © 2017 Arm Ltd. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
-#include "MemSyncWorkload.hpp"
-
-#include "CpuTensorHandle.hpp"
-
 #include <ResolveType.hpp>
 
+#include <backendsCommon/MemSyncWorkload.hpp>
+#include <backendsCommon/CpuTensorHandle.hpp>
+
 #include <boost/cast.hpp>
 
 #include <cstring>
