@@ -5,25 +5,26 @@
 
 #pragma once
 
-#include <backendsCommon/DynamicBackend.hpp>
-#include <backendsCommon/DynamicBackendUtils.hpp>
-#include <backendsCommon/CpuTensorHandle.hpp>
-
-#include <armnn/ILayerSupport.hpp>
 #include <armnn/BackendRegistry.hpp>
-
+#include <armnn/backends/DynamicBackend.hpp>
+#include <armnn/ILayerSupport.hpp>
+#include <armnn/utility/PolymorphicDowncast.hpp>
+#include <backendsCommon/CpuTensorHandle.hpp>
+#include <backendsCommon/DynamicBackendUtils.hpp>
+#include <Filesystem.hpp>
 #include <reference/workloads/RefConvolution2dWorkload.hpp>
-
 #include <Runtime.hpp>
 
 #include <string>
 #include <memory>
-#include <string>
 
 #include <boost/test/unit_test.hpp>
-#include <boost/filesystem.hpp>
-#include <boost/dll.hpp>
 
+#if !defined(DYNAMIC_BACKEND_BUILD_DIR)
+#define DYNAMIC_BACKEND_BUILD_DIR fs::path("./")
+#endif
+
+static std::string g_TestDirCLI                             = "--dynamic-backend-build-dir";
 static std::string g_TestBaseDir                            = "src/backends/backendsCommon/test/";
 
 static std::string g_TestSharedObjectSubDir                 = "testSharedObject/";
@@ -107,12 +108,48 @@ private:
 
 std::string GetBasePath(const std::string& basePath)
 {
-    using namespace boost::filesystem;
-
-    path programLocation = boost::dll::program_location().parent_path();
+    using namespace fs;
+    // What we're looking for here is the location of the UnitTests executable.
+    // In the normal build environment there are a series of files and
+    // directories created by cmake. If the executable has been relocated they
+    // may not be there. The search hierarchy is:
+    // * User specified --dynamic-backend-build-dir
+    // * Compile time value of DYNAMIC_BACKEND_BUILD_DIR.
+    // * Arg0 location.
+    // * Fall back value of current directory.
+    path programLocation = DYNAMIC_BACKEND_BUILD_DIR;
+    // Look for the specific argument --dynamic-backend-build-dir?
+    if (boost::unit_test::framework::master_test_suite().argc == 3)
+    {
+        // Boost custom arguments begin after a '--' on the command line.
+        if (g_TestDirCLI.compare(boost::unit_test::framework::master_test_suite().argv[1]) == 0)
+        {
+            // Then the next argument is the path.
+            programLocation = boost::unit_test::framework::master_test_suite().argv[2];
+        }
+    }
+    else
+    {
+        // Start by checking if DYNAMIC_BACKEND_BUILD_DIR value exist.
+        if (!exists(programLocation))
+        {
+            // That doesn't exist try looking at arg[0].
+            path arg0Path(boost::unit_test::framework::master_test_suite().argv[0]);
+            arg0Path.remove_filename();
+            path arg0SharedObjectPath(arg0Path);
+            arg0SharedObjectPath.append(basePath);
+            if (exists(arg0SharedObjectPath))
+            {
+                // Yeah arg0 worked.
+                programLocation = arg0Path;
+            }
+        }
+    }
+    // This is the base path from the build where the test libraries were built.
     path sharedObjectPath = programLocation.append(basePath);
-    BOOST_CHECK(exists(sharedObjectPath));
-
+    BOOST_REQUIRE_MESSAGE(exists(sharedObjectPath), "Base path for shared objects does not exist: " +
+                          sharedObjectPath.string() + "\nTo specify the root of this base path on the " +
+                          "command line add: \'-- --dynamic-backend-build-dir <path>\'");
     return sharedObjectPath.string();
 }
 
@@ -128,7 +165,7 @@ std::string GetDynamicBackendsBasePath()
 
 std::string GetTestSubDirectory(const std::string& subdir)
 {
-    using namespace boost::filesystem;
+    using namespace fs;
 
     std::string testDynamicBackendsBaseDir = GetTestDirectoryBasePath();
     path testDynamicBackendsBasePath(testDynamicBackendsBaseDir);
@@ -140,7 +177,7 @@ std::string GetTestSubDirectory(const std::string& subdir)
 
 std::string GetTestSubDirectory(const std::string& basePath, const std::string& subdir)
 {
-    using namespace boost::filesystem;
+    using namespace fs;
 
     path testDynamicBackendsBasePath(basePath);
     path testDynamicBackendsSubDir = testDynamicBackendsBasePath.append(subdir);
@@ -151,7 +188,7 @@ std::string GetTestSubDirectory(const std::string& basePath, const std::string&
 
 std::string GetTestFilePath(const std::string& directory, const std::string& fileName)
 {
-    using namespace boost::filesystem;
+    using namespace fs;
 
     path directoryPath(directory);
     path fileNamePath = directoryPath.append(fileName);
@@ -347,6 +384,11 @@ void CreateValidDynamicBackendObjectTestImpl()
     using namespace armnn;
 
     std::string testSubDirectory = GetTestSubDirectory(g_TestDynamicBackendSubDir);
+
+    // We expect this path to exists so we can load a valid dynamic backend.
+    BOOST_CHECK_MESSAGE(fs::exists(testSubDirectory),
+                       "Base path for shared objects does not exist: " + testSubDirectory);
+
     std::string sharedObjectFilePath = GetTestFilePath(testSubDirectory, g_TestValidTestDynamicBackendFileName);
 
     void* sharedObjectHandle = nullptr;
@@ -558,7 +600,7 @@ void CreateDynamicBackendObjectInvalidInterface7TestImpl()
 void GetBackendPathsTestImpl()
 {
     using namespace armnn;
-    using namespace boost::filesystem;
+    using namespace fs;
 
     // The test covers four directories:
     // <unit test path>/src/backends/backendsCommon/test/
@@ -638,7 +680,7 @@ void GetBackendPathsTestImpl()
 void GetBackendPathsOverrideTestImpl()
 {
     using namespace armnn;
-    using namespace boost::filesystem;
+    using namespace fs;
 
     std::string subDir1 = GetTestSubDirectory(g_TestDynamicBackendsSubDir1);
     std::string subDir4 = GetTestSubDirectory(g_TestDynamicBackendsSubDir4);
@@ -659,7 +701,7 @@ void GetBackendPathsOverrideTestImpl()
 void GetSharedObjectsTestImpl()
 {
     using namespace armnn;
-    using namespace boost::filesystem;
+    using namespace fs;
 
     // The test covers four directories:
     // <unit test path>/src/backends/backendsCommon/test/
@@ -722,35 +764,35 @@ void GetSharedObjectsTestImpl()
         testDynamicBackendsSubDir4
     };
     std::vector<std::string> sharedObjects = DynamicBackendUtils::GetSharedObjects(backendPaths);
-    std::vector<std::string> expectedSharedObjects
+    std::vector<fs::path> expectedSharedObjects
     {
-        testDynamicBackendsSubDir1 + "Arm123_GpuAcc_backend.so",      // Digits in vendor name are allowed
-        testDynamicBackendsSubDir1 + "Arm_GpuAcc456_backend.so",      // Digits in backend id are allowed
-        testDynamicBackendsSubDir1 + "Arm_GpuAcc_backend.so",         // Basic backend name
-        testDynamicBackendsSubDir1 + "Arm_GpuAcc_backend.so.1",       // Single field version number
-        testDynamicBackendsSubDir1 + "Arm_GpuAcc_backend.so.1.2",     // Multiple field version number
-        testDynamicBackendsSubDir1 + "Arm_GpuAcc_backend.so.1.2.3",   // Multiple field version number
-        testDynamicBackendsSubDir1 + "Arm_GpuAcc_backend.so.10.1.27", // Multiple digit version
-        testDynamicBackendsSubDir2 + "Arm_CpuAcc_backend.so",         // Duplicate symlinks removed
-        testDynamicBackendsSubDir2 + "Arm_GpuAcc_backend.so"          // Duplicates on different paths are allowed
+        path(testDynamicBackendsSubDir1 + "Arm123_GpuAcc_backend.so"),      // Digits in vendor name are allowed
+        path(testDynamicBackendsSubDir1 + "Arm_GpuAcc456_backend.so"),      // Digits in backend id are allowed
+        path(testDynamicBackendsSubDir1 + "Arm_GpuAcc_backend.so"),         // Basic backend name
+        path(testDynamicBackendsSubDir1 + "Arm_GpuAcc_backend.so.1"),       // Single field version number
+        path(testDynamicBackendsSubDir1 + "Arm_GpuAcc_backend.so.1.2"),     // Multiple field version number
+        path(testDynamicBackendsSubDir1 + "Arm_GpuAcc_backend.so.1.2.3"),   // Multiple field version number
+        path(testDynamicBackendsSubDir1 + "Arm_GpuAcc_backend.so.10.1.27"), // Multiple digit version
+        path(testDynamicBackendsSubDir2 + "Arm_CpuAcc_backend.so"),         // Duplicate symlinks removed
+        path(testDynamicBackendsSubDir2 + "Arm_GpuAcc_backend.so")          // Duplicates on different paths are allowed
     };
 
     BOOST_TEST(sharedObjects.size() == expectedSharedObjects.size());
-    BOOST_TEST(sharedObjects[0] == expectedSharedObjects[0]);
-    BOOST_TEST(sharedObjects[1] == expectedSharedObjects[1]);
-    BOOST_TEST(sharedObjects[2] == expectedSharedObjects[2]);
-    BOOST_TEST(sharedObjects[3] == expectedSharedObjects[3]);
-    BOOST_TEST(sharedObjects[4] == expectedSharedObjects[4]);
-    BOOST_TEST(sharedObjects[5] == expectedSharedObjects[5]);
-    BOOST_TEST(sharedObjects[6] == expectedSharedObjects[6]);
-    BOOST_TEST(sharedObjects[7] == expectedSharedObjects[7]);
-    BOOST_TEST(sharedObjects[8] == expectedSharedObjects[8]);
+    BOOST_TEST(fs::equivalent(path(sharedObjects[0]), expectedSharedObjects[0]));
+    BOOST_TEST(fs::equivalent(path(sharedObjects[1]), expectedSharedObjects[1]));
+    BOOST_TEST(fs::equivalent(path(sharedObjects[2]), expectedSharedObjects[2]));
+    BOOST_TEST(fs::equivalent(path(sharedObjects[3]), expectedSharedObjects[3]));
+    BOOST_TEST(fs::equivalent(path(sharedObjects[4]), expectedSharedObjects[4]));
+    BOOST_TEST(fs::equivalent(path(sharedObjects[5]), expectedSharedObjects[5]));
+    BOOST_TEST(fs::equivalent(path(sharedObjects[6]), expectedSharedObjects[6]));
+    BOOST_TEST(fs::equivalent(path(sharedObjects[7]), expectedSharedObjects[7]));
+    BOOST_TEST(fs::equivalent(path(sharedObjects[8]), expectedSharedObjects[8]));
 }
 
 void CreateDynamicBackendsTestImpl()
 {
     using namespace armnn;
-    using namespace boost::filesystem;
+    using namespace fs;
 
     // The test covers four directories:
     // <unit test path>/src/backends/backendsCommon/test/
@@ -837,7 +879,7 @@ void CreateDynamicBackendsAllInvalidTestImpl()
 void CreateDynamicBackendsMixedTypesTestImpl()
 {
     using namespace armnn;
-    using namespace boost::filesystem;
+    using namespace fs;
 
     std::string testDynamicBackendsSubDir5 = GetTestSubDirectory(g_TestDynamicBackendsSubDir5);
     std::string testDynamicBackendsSubDir6 = GetTestSubDirectory(g_TestDynamicBackendsSubDir6);
@@ -871,7 +913,7 @@ void CreateDynamicBackendsMixedTypesTestImpl()
 void RegisterSingleDynamicBackendTestImpl()
 {
     using namespace armnn;
-    using namespace boost::filesystem;
+    using namespace fs;
 
     // Register one valid dynamic backend
 
@@ -918,7 +960,7 @@ void RegisterSingleDynamicBackendTestImpl()
 void RegisterMultipleDynamicBackendsTestImpl()
 {
     using namespace armnn;
-    using namespace boost::filesystem;
+    using namespace fs;
 
     // Register many valid dynamic backends
 
@@ -994,7 +1036,7 @@ void RegisterMultipleDynamicBackendsTestImpl()
 void RegisterMultipleInvalidDynamicBackendsTestImpl()
 {
     using namespace armnn;
-    using namespace boost::filesystem;
+    using namespace fs;
 
     // Try to register many invalid dynamic backends
 
@@ -1054,7 +1096,7 @@ void RegisterMultipleInvalidDynamicBackendsTestImpl()
 void RegisterMixedDynamicBackendsTestImpl()
 {
     using namespace armnn;
-    using namespace boost::filesystem;
+    using namespace fs;
 
     // The test covers five directories:
     // <unit test path>/src/backends/backendsCommon/test/
@@ -1197,6 +1239,8 @@ void RegisterMixedDynamicBackendsTestImpl()
     }
 }
 
+#if !defined(ARMNN_DYNAMIC_BACKEND_ENABLED)
+
 void RuntimeEmptyTestImpl()
 {
     using namespace armnn;
@@ -1210,17 +1254,19 @@ void RuntimeEmptyTestImpl()
     IRuntime::CreationOptions creationOptions;
     IRuntimePtr runtime = IRuntime::Create(creationOptions);
 
-    const DeviceSpec& deviceSpec = *boost::polymorphic_downcast<const DeviceSpec*>(&runtime->GetDeviceSpec());
+    const DeviceSpec& deviceSpec = *PolymorphicDowncast<const DeviceSpec*>(&runtime->GetDeviceSpec());
     BackendIdSet supportedBackendIds = deviceSpec.GetSupportedBackends();
     BOOST_TEST(supportedBackendIds.empty());
 
     BOOST_TEST(backendRegistry.Size() == 0);
 }
 
+#endif
+
 void RuntimeDynamicBackendsTestImpl()
 {
     using namespace armnn;
-    using namespace boost::filesystem;
+    using namespace fs;
 
     // Swapping the backend registry storage for testing
     TestBackendRegistry testBackendRegistry;
@@ -1249,7 +1295,7 @@ void RuntimeDynamicBackendsTestImpl()
         BOOST_TEST((backendIds.find(expectedRegisteredbackendId) != backendIds.end()));
     }
 
-    const DeviceSpec& deviceSpec = *boost::polymorphic_downcast<const DeviceSpec*>(&runtime->GetDeviceSpec());
+    const DeviceSpec& deviceSpec = *PolymorphicDowncast<const DeviceSpec*>(&runtime->GetDeviceSpec());
     BackendIdSet supportedBackendIds = deviceSpec.GetSupportedBackends();
     BOOST_TEST(supportedBackendIds.size() == expectedRegisteredbackendIds.size());
     for (const BackendId& expectedRegisteredbackendId : expectedRegisteredbackendIds)
@@ -1261,7 +1307,7 @@ void RuntimeDynamicBackendsTestImpl()
 void RuntimeDuplicateDynamicBackendsTestImpl()
 {
     using namespace armnn;
-    using namespace boost::filesystem;
+    using namespace fs;
 
     // Swapping the backend registry storage for testing
     TestBackendRegistry testBackendRegistry;
@@ -1290,7 +1336,7 @@ void RuntimeDuplicateDynamicBackendsTestImpl()
         BOOST_TEST((backendIds.find(expectedRegisteredbackendId) != backendIds.end()));
     }
 
-    const DeviceSpec& deviceSpec = *boost::polymorphic_downcast<const DeviceSpec*>(&runtime->GetDeviceSpec());
+    const DeviceSpec& deviceSpec = *PolymorphicDowncast<const DeviceSpec*>(&runtime->GetDeviceSpec());
     BackendIdSet supportedBackendIds = deviceSpec.GetSupportedBackends();
     BOOST_TEST(supportedBackendIds.size() == expectedRegisteredbackendIds.size());
     for (const BackendId& expectedRegisteredbackendId : expectedRegisteredbackendIds)
@@ -1302,7 +1348,7 @@ void RuntimeDuplicateDynamicBackendsTestImpl()
 void RuntimeInvalidDynamicBackendsTestImpl()
 {
     using namespace armnn;
-    using namespace boost::filesystem;
+    using namespace fs;
 
     // Swapping the backend registry storage for testing
     TestBackendRegistry testBackendRegistry;
@@ -1319,7 +1365,7 @@ void RuntimeInvalidDynamicBackendsTestImpl()
     const BackendRegistry& backendRegistry = BackendRegistryInstance();
     BOOST_TEST(backendRegistry.Size() == 0);
 
-    const DeviceSpec& deviceSpec = *boost::polymorphic_downcast<const DeviceSpec*>(&runtime->GetDeviceSpec());
+    const DeviceSpec& deviceSpec = *PolymorphicDowncast<const DeviceSpec*>(&runtime->GetDeviceSpec());
     BackendIdSet supportedBackendIds = deviceSpec.GetSupportedBackends();
     BOOST_TEST(supportedBackendIds.empty());
 }
@@ -1339,7 +1385,7 @@ void RuntimeInvalidOverridePathTestImpl()
     const BackendRegistry& backendRegistry = BackendRegistryInstance();
     BOOST_TEST(backendRegistry.Size() == 0);
 
-    const DeviceSpec& deviceSpec = *boost::polymorphic_downcast<const DeviceSpec*>(&runtime->GetDeviceSpec());
+    const DeviceSpec& deviceSpec = *PolymorphicDowncast<const DeviceSpec*>(&runtime->GetDeviceSpec());
     BackendIdSet supportedBackendIds = deviceSpec.GetSupportedBackends();
     BOOST_TEST(supportedBackendIds.empty());
 }
@@ -1351,7 +1397,7 @@ void RuntimeInvalidOverridePathTestImpl()
 void CreateReferenceDynamicBackendTestImpl()
 {
     using namespace armnn;
-    using namespace boost::filesystem;
+    using namespace fs;
 
     // Swapping the backend registry storage for testing
     TestBackendRegistry testBackendRegistry;
@@ -1378,7 +1424,7 @@ void CreateReferenceDynamicBackendTestImpl()
     BackendIdSet backendIds = backendRegistry.GetBackendIds();
     BOOST_TEST((backendIds.find("CpuRef") != backendIds.end()));
 
-    const DeviceSpec& deviceSpec = *boost::polymorphic_downcast<const DeviceSpec*>(&runtime->GetDeviceSpec());
+    const DeviceSpec& deviceSpec = *PolymorphicDowncast<const DeviceSpec*>(&runtime->GetDeviceSpec());
     BackendIdSet supportedBackendIds = deviceSpec.GetSupportedBackends();
     BOOST_TEST(supportedBackendIds.size() == 1);
     BOOST_TEST((supportedBackendIds.find("CpuRef") != supportedBackendIds.end()));
@@ -1429,7 +1475,138 @@ void CreateReferenceDynamicBackendTestImpl()
     // Create a convolution workload with the dummy settings
     auto workload = referenceWorkloadFactory->CreateConvolution2d(convolution2dQueueDescriptor, workloadInfo);
     BOOST_TEST((workload != nullptr));
-    BOOST_TEST(workload.get() == boost::polymorphic_downcast<RefConvolution2dWorkload*>(workload.get()));
+    BOOST_TEST(workload.get() == PolymorphicDowncast<RefConvolution2dWorkload*>(workload.get()));
 }
 
 #endif
+
+#if defined(SAMPLE_DYNAMIC_BACKEND_ENABLED)
+
+void CheckSampleDynamicBackendLoaded()
+{
+    using namespace armnn;
+    // At this point we expect DYNAMIC_BACKEND_PATHS to include a path to where libArm_SampleDynamic_backend.so is.
+    // If it hasn't been loaded there's no point continuing with the rest of the tests.
+    BackendIdSet backendIds = BackendRegistryInstance().GetBackendIds();
+    if (backendIds.find("SampleDynamic") == backendIds.end())
+    {
+        std::string message = "The SampleDynamic backend has not been loaded. This may be a build configuration error. "
+                              "Ensure a DYNAMIC_BACKEND_PATHS was set at compile time to the location of "
+                              "libArm_SampleDynamic_backend.so. "
+                              "To disable this test recompile with: -DSAMPLE_DYNAMIC_BACKEND_ENABLED=0";
+        BOOST_FAIL(message);
+    }
+}
+
+void CreateSampleDynamicBackendTestImpl()
+{
+    using namespace armnn;
+    // Using the path override in CreationOptions to load the reference dynamic backend
+    IRuntime::CreationOptions creationOptions;
+    IRuntimePtr runtime = IRuntime::Create(creationOptions);
+    const BackendRegistry& backendRegistry = BackendRegistryInstance();
+    BOOST_TEST(backendRegistry.Size() >= 1);
+    CheckSampleDynamicBackendLoaded();
+    const DeviceSpec& deviceSpec = *PolymorphicDowncast<const DeviceSpec*>(&runtime->GetDeviceSpec());
+    BackendIdSet supportedBackendIds = deviceSpec.GetSupportedBackends();
+    BOOST_TEST(supportedBackendIds.size()>= 1);
+    BOOST_TEST((supportedBackendIds.find("SampleDynamic") != supportedBackendIds.end()));
+
+    // Get the factory function
+    auto sampleDynamicBackendFactoryFunction = backendRegistry.GetFactory("SampleDynamic");
+    BOOST_TEST((sampleDynamicBackendFactoryFunction != nullptr));
+
+    // Use the factory function to create an instance of the dynamic backend
+    IBackendInternalUniquePtr sampleDynamicBackend = sampleDynamicBackendFactoryFunction();
+    BOOST_TEST((sampleDynamicBackend != nullptr));
+    BOOST_TEST((sampleDynamicBackend->GetId() == "SampleDynamic"));
+
+    // Test the backend instance by querying the layer support
+    IBackendInternal::ILayerSupportSharedPtr sampleLayerSupport = sampleDynamicBackend->GetLayerSupport();
+    BOOST_TEST((sampleLayerSupport != nullptr));
+
+    TensorShape inputShape {  1, 16, 16, 16 };
+    TensorShape outputShape{  1, 16, 16, 16 };
+    TensorShape weightShape{ 16,  1,  1, 16 };
+    TensorInfo inputInfo (inputShape,  DataType::Float32);
+    TensorInfo outputInfo(outputShape, DataType::Float32);
+    TensorInfo weightInfo(weightShape, DataType::Float32);
+    Convolution2dDescriptor convolution2dDescriptor;
+    bool sampleConvolution2dSupported =
+            sampleLayerSupport->IsConvolution2dSupported(inputInfo,
+                                                         outputInfo,
+                                                         convolution2dDescriptor,
+                                                         weightInfo,
+                                                         EmptyOptional());
+    BOOST_TEST(!sampleConvolution2dSupported);
+
+    // Test the backend instance by creating a workload
+    IBackendInternal::IWorkloadFactoryPtr sampleWorkloadFactory = sampleDynamicBackend->CreateWorkloadFactory();
+    BOOST_TEST((sampleWorkloadFactory != nullptr));
+
+    // Create dummy settings for the workload
+    AdditionQueueDescriptor additionQueueDescriptor;
+    WorkloadInfo workloadInfo
+    {
+        { inputInfo, inputInfo },
+        { outputInfo }
+    };
+
+    // Create a addition workload
+    auto workload = sampleWorkloadFactory->CreateAddition(additionQueueDescriptor, workloadInfo);
+    BOOST_TEST((workload != nullptr));
+}
+
+void SampleDynamicBackendEndToEndTestImpl()
+{
+    using namespace armnn;
+    // Create runtime in which test will run
+    IRuntime::CreationOptions options;
+    IRuntimePtr runtime(IRuntime::Create(options));
+    CheckSampleDynamicBackendLoaded();
+    // Builds up the structure of the network.
+    INetworkPtr net(INetwork::Create());
+
+    IConnectableLayer* input0 = net->AddInputLayer(0);
+    IConnectableLayer* input1 = net->AddInputLayer(1);
+    IConnectableLayer* add = net->AddAdditionLayer();
+    IConnectableLayer* output = net->AddOutputLayer(0);
+
+    input0->GetOutputSlot(0).Connect(add->GetInputSlot(0));
+    input1->GetOutputSlot(0).Connect(add->GetInputSlot(1));
+    add->GetOutputSlot(0).Connect(output->GetInputSlot(0));
+
+    TensorInfo tensorInfo(TensorShape({2, 1}), DataType::Float32);
+    input0->GetOutputSlot(0).SetTensorInfo(tensorInfo);
+    input1->GetOutputSlot(0).SetTensorInfo(tensorInfo);
+    add->GetOutputSlot(0).SetTensorInfo(tensorInfo);
+
+    // optimize the network
+    IOptimizedNetworkPtr optNet = Optimize(*net, {"SampleDynamic"}, runtime->GetDeviceSpec());
+
+    // Loads it into the runtime.
+    NetworkId netId;
+    runtime->LoadNetwork(netId, std::move(optNet));
+
+    std::vector<float> input0Data{ 5.0f, 3.0f };
+    std::vector<float> input1Data{ 10.0f, 8.0f };
+    std::vector<float> expectedOutputData{ 15.0f, 11.0f };
+    std::vector<float> outputData(2);
+
+    InputTensors inputTensors
+        {
+            {0,armnn::ConstTensor(runtime->GetInputTensorInfo(netId, 0), input0Data.data())},
+            {1,armnn::ConstTensor(runtime->GetInputTensorInfo(netId, 0), input1Data.data())}
+        };
+    OutputTensors outputTensors
+        {
+            {0,armnn::Tensor(runtime->GetOutputTensorInfo(netId, 0), outputData.data())}
+        };
+
+    // Does the inference.
+    runtime->EnqueueWorkload(netId, inputTensors, outputTensors);
+
+    // Checks the results.
+    BOOST_TEST(outputData == expectedOutputData);
+}
+#endif
