@@ -1,5 +1,5 @@
 //
-// Copyright © 2017 Arm Ltd. All rights reserved.
+// Copyright © 2017 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
@@ -9,9 +9,8 @@
 
 #include <ResolveType.hpp>
 
-#include <armnn/ArmNN.hpp>
 
-#include <backendsCommon/IBackendInternal.hpp>
+#include <armnn/backends/IBackendInternal.hpp>
 #include <backendsCommon/WorkloadFactory.hpp>
 
 #include <backendsCommon/test/DataTypeUtils.hpp>
@@ -40,6 +39,8 @@ LayerTestResult<T, OutputDim> BatchToSpaceNdHelper(
         float scale = 1.0f,
         int32_t offset = 0)
 {
+    IgnoreUnused(memoryManager);
+
     armnn::TensorInfo inputTensorInfo(InputDim, inputShape, ArmnnType);
     armnn::TensorInfo outputTensorInfo(OutputDim, outputShape, ArmnnType);
 
@@ -55,8 +56,10 @@ LayerTestResult<T, OutputDim> BatchToSpaceNdHelper(
     result.outputExpected = MakeTensor<T, OutputDim>(outputTensorInfo,
                                                      ConvertToDataType<ArmnnType>(outputData, outputTensorInfo));
 
+    ARMNN_NO_DEPRECATE_WARN_BEGIN
     std::unique_ptr<armnn::ITensorHandle> inputHandle = workloadFactory.CreateTensorHandle(inputTensorInfo);
     std::unique_ptr<armnn::ITensorHandle> outputHandle = workloadFactory.CreateTensorHandle(outputTensorInfo);
+    ARMNN_NO_DEPRECATE_WARN_END
 
     armnn::BatchToSpaceNdQueueDescriptor data;
     data.m_Parameters.m_DataLayout = dataLayout;
