@@ -7,7 +7,7 @@
 
 #include "LayerTestResult.hpp"
 
-#include <backendsCommon/IBackendInternal.hpp>
+#include <armnn/backends/IBackendInternal.hpp>
 #include <backendsCommon/WorkloadFactory.hpp>
 
 LayerTestResult<float, 2> FakeQuantizationTest(
