@@ -6,7 +6,7 @@
 #pragma once
 
 #include <backendsCommon/Workload.hpp>
-#include <arm_compute/runtime/CL/CLFunctions.h>
+#include <arm_compute/runtime/CL/functions/CLBatchToSpaceLayer.h>
 
 namespace armnn
 {
