@@ -7,7 +7,7 @@
 
 #include <backendsCommon/Workload.hpp>
 
-#include <arm_compute/runtime/CL/CLFunctions.h>
+#include <arm_compute/runtime/CL/functions/CLElementwiseOperations.h>
 
 namespace armnn
 {
@@ -26,4 +26,4 @@ private:
     mutable arm_compute::CLElementwiseMax m_MaximumLayer;
 };
 
-} //namespace armnn
\ No newline at end of file
+} //namespace armnn
