@@ -1,4 +1,4 @@
-﻿//
+//
 // Copyright © 2017 Arm Ltd. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
@@ -6,8 +6,10 @@
 #include "NeonConvertFp32ToFp16Workload.hpp"
 
 #include <Half.hpp>
-#include <FloatingPointConverter.hpp>
 #include <Profiling.hpp>
+
+#include <armnnUtils/FloatingPointConverter.hpp>
+
 #include <backendsCommon/WorkloadUtils.hpp>
 
 namespace armnn
