@@ -7,7 +7,8 @@
 
 #include <backendsCommon/Workload.hpp>
 
-#include <arm_compute/runtime/NEON/NEFunctions.h>
+#include <arm_compute/core/Error.h>
+#include <arm_compute/runtime/IFunction.h>
 
 #include <functional>
 
@@ -25,7 +26,7 @@ public:
     void Execute() const override;
 
 private:
-    mutable std::unique_ptr<arm_compute::NEDequantizationLayer> m_Layer;
+    mutable std::unique_ptr<arm_compute::IFunction> m_Layer;
 };
 
 } //namespace armnn
