@@ -1,15 +1,15 @@
-﻿//
+//
 // Copyright © 2017 Arm Ltd. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #include "RefConvertFp32ToFp16Workload.hpp"
-
-#include "FloatingPointConverter.hpp"
 #include "RefWorkloadUtils.hpp"
 #include "Profiling.hpp"
 
-#include "Half.hpp"
+#include <armnnUtils/FloatingPointConverter.hpp>
+
+#include <Half.hpp>
 
 namespace armnn
 {
