@@ -1,4 +1,4 @@
-﻿//
+//
 // Copyright © 2017 Arm Ltd. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
@@ -44,9 +44,13 @@ void RefDebugWorkload<DataType>::RegisterDebugCallback(const DebugCallbackFuncti
     m_Callback = func;
 }
 
+template class RefDebugWorkload<DataType::BFloat16>;
 template class RefDebugWorkload<DataType::Float16>;
 template class RefDebugWorkload<DataType::Float32>;
-template class RefDebugWorkload<DataType::QuantisedAsymm8>;
-template class RefDebugWorkload<DataType::QuantisedSymm16>;
+template class RefDebugWorkload<DataType::QAsymmU8>;
+template class RefDebugWorkload<DataType::QAsymmS8>;
+template class RefDebugWorkload<DataType::QSymmS16>;
+template class RefDebugWorkload<DataType::QSymmS8>;
+template class RefDebugWorkload<DataType::Signed32>;
 
 } // namespace armnn
