@@ -1,4 +1,4 @@
-﻿//
+//
 // Copyright © 2017 Arm Ltd. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
@@ -37,9 +37,13 @@ private:
     DebugCallbackFunction m_Callback;
 };
 
-using RefDebugFloat16Workload = RefDebugWorkload<DataType::Float16>;
-using RefDebugFloat32Workload = RefDebugWorkload<DataType::Float32>;
-using RefDebugQAsymm8Workload = RefDebugWorkload<DataType::QuantisedAsymm8>;
-using RefDebugQSymm16Workload = RefDebugWorkload<DataType::QuantisedSymm16>;
+using RefDebugBFloat16Workload   = RefDebugWorkload<DataType::BFloat16>;
+using RefDebugFloat16Workload   = RefDebugWorkload<DataType::Float16>;
+using RefDebugFloat32Workload   = RefDebugWorkload<DataType::Float32>;
+using RefDebugQAsymmU8Workload  = RefDebugWorkload<DataType::QAsymmU8>;
+using RefDebugQAsymmS8Workload  = RefDebugWorkload<DataType::QAsymmS8>;
+using RefDebugQSymmS16Workload  = RefDebugWorkload<DataType::QSymmS16>;
+using RefDebugQSymmS8Workload   = RefDebugWorkload<DataType::QSymmS8>;
+using RefDebugSigned32Workload  = RefDebugWorkload<DataType::Signed32>;
 
 } // namespace armnn
