@@ -1,4 +1,4 @@
-﻿//
+//
 // Copyright © 2017 Arm Ltd. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
@@ -6,7 +6,8 @@
 #include "RefPermuteWorkload.hpp"
 #include "RefWorkloadUtils.hpp"
 
-#include <Permute.hpp>
+#include <armnnUtils/Permute.hpp>
+
 #include <ResolveType.hpp>
 
 namespace armnn
@@ -27,9 +28,11 @@ void RefPermuteWorkload<DataType>::Execute() const
                         src->Map(), dst->Map(), sizeof(T));
 }
 
+template class RefPermuteWorkload<DataType::BFloat16>;
 template class RefPermuteWorkload<DataType::Float16>;
 template class RefPermuteWorkload<DataType::Float32>;
-template class RefPermuteWorkload<DataType::QuantisedAsymm8>;
-template class RefPermuteWorkload<DataType::QuantisedSymm16>;
+template class RefPermuteWorkload<DataType::QAsymmS8>;
+template class RefPermuteWorkload<DataType::QAsymmU8>;
+template class RefPermuteWorkload<DataType::QSymmS16>;
 
 } //namespace armnn
