@@ -7,6 +7,8 @@
 
 #include <backendsCommon/Workload.hpp>
 #include <backendsCommon/WorkloadData.hpp>
+#include "Decoders.hpp"
+#include "Encoders.hpp"
 
 namespace armnn {
 
@@ -14,13 +16,15 @@ class RefQuantizeWorkload : public BaseWorkload<QuantizeQueueDescriptor>
 {
 public:
     RefQuantizeWorkload(const QuantizeQueueDescriptor& descriptor, const WorkloadInfo &info);
+    void PostAllocationConfigure() override;
     void Execute() const override;
 
 private:
+
+    std::unique_ptr<Decoder<float>> m_InputDecoder;
+    std::unique_ptr<Encoder<float>> m_OutputEncoder;
+
     size_t m_NumElements;
-    armnn::DataType m_TargetType;
-    float m_Scale;
-    int m_Offset;
 };
 
 } //namespace armnn
\ No newline at end of file
