@@ -1,10 +1,10 @@
-﻿//
+//
 // Copyright © 2017 Arm Ltd. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 #pragma once
 
-#include "backendsCommon/Workload.hpp"
+#include <backendsCommon/Workload.hpp>
 
 #include <armnn/TypesUtils.hpp>
 
