@@ -1,4 +1,4 @@
-﻿//
+//
 // Copyright © 2017 Arm Ltd. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
@@ -6,9 +6,10 @@
 #pragma once
 
 #include "BaseIterator.hpp"
+
 #include <armnn/Tensor.hpp>
 
-#include <DataLayoutIndexed.hpp>
+#include <armnnUtils/DataLayoutIndexed.hpp>
 
 namespace armnn
 {
@@ -18,6 +19,8 @@ void Resize(Decoder<float>&               in,
             Encoder<float>&               out,
             const TensorInfo&             outputInfo,
             armnnUtils::DataLayoutIndexed dataLayout = DataLayout::NCHW,
-            ResizeMethod                  resizeMethod = ResizeMethod::NearestNeighbor);
+            ResizeMethod                  resizeMethod = ResizeMethod::NearestNeighbor,
+            bool                          alignCorners = false,
+            bool                          halfPixelCenters = false);
 
-} //namespace armnn
+} // namespace armnn
