@@ -6,10 +6,12 @@
 #pragma once
 
 #include "IBufferManager.hpp"
+#include "IConsumer.hpp"
 
 #include <condition_variable>
 #include <mutex>
 #include <vector>
+#include <queue>
 
 namespace armnn
 {
@@ -26,7 +28,9 @@ public:
 
     IPacketBufferPtr Reserve(unsigned int requestedSize, unsigned int& reservedSize) override;
 
-    void Commit(IPacketBufferPtr& packetBuffer, unsigned int size) override;
+    void Reset();
+
+    void Commit(IPacketBufferPtr& packetBuffer, unsigned int size, bool notifyConsumer = true) override;
 
     void Release(IPacketBufferPtr& packetBuffer) override;
 
@@ -34,15 +38,28 @@ public:
 
     void MarkRead(IPacketBufferPtr& packetBuffer) override;
 
+    /// Set Consumer on the buffer manager to be notified when there is a Commit
+    /// Can only be one consumer
+    void SetConsumer(IConsumer* consumer) override;
+
+    /// Notify the Consumer buffer can be read
+    void FlushReadList() override;
+
 private:
+    void Initialize();
+
     // Maximum buffer size
     unsigned int m_MaxBufferSize;
+    // Number of buffers
+    const unsigned int m_NumberOfBuffers;
+    const unsigned int m_MaxNumberOfBuffers;
+    unsigned int m_CurrentNumberOfBuffers;
 
     // List of available packet buffers
     std::vector<IPacketBufferPtr> m_AvailableList;
 
     // List of readable packet buffers
-    std::vector<IPacketBufferPtr> m_ReadableList;
+    std::queue<IPacketBufferPtr> m_ReadableList;
 
     // Mutex for available packet buffer list
     std::mutex m_AvailableMutex;
@@ -50,8 +67,8 @@ private:
     // Mutex for readable packet buffer list
     std::mutex m_ReadableMutex;
 
-    // Condition to notify when data is availabe to be read
-    std::condition_variable m_ReadDataAvailable;
+    // Consumer thread to notify packet is ready to read
+    IConsumer* m_Consumer = nullptr;
 };
 
 } // namespace profiling
