@@ -20,7 +20,8 @@ public:
 
     virtual bool IsCounterRegistered(uint16_t counterUid) const = 0;
     virtual uint16_t GetCounterCount() const = 0;
-    virtual uint32_t GetCounterValue(uint16_t counterUid) const = 0;
+    virtual uint32_t GetAbsoluteCounterValue(uint16_t counterUid) const = 0;
+    virtual uint32_t GetDeltaCounterValue(uint16_t counterUid) = 0;
 };
 
 class IWriteCounterValues
@@ -32,7 +33,6 @@ public:
     virtual uint32_t AddCounterValue(uint16_t counterUid, uint32_t value) = 0;
     virtual uint32_t SubtractCounterValue(uint16_t counterUid, uint32_t value) = 0;
     virtual uint32_t IncrementCounterValue(uint16_t counterUid) = 0;
-    virtual uint32_t DecrementCounterValue(uint16_t counterUid) = 0;
 };
 
 class IReadWriteCounterValues : public IReadCounterValues, public IWriteCounterValues
