@@ -18,7 +18,7 @@ class IReadOnlyPacketBuffer // interface used by the read thread
 public:
     virtual ~IReadOnlyPacketBuffer() {}
 
-    virtual const unsigned char* const GetReadableData() const = 0;
+    virtual const unsigned char* GetReadableData() const = 0;
 
     virtual unsigned int GetSize() const = 0;
 
@@ -35,6 +35,10 @@ public:
     virtual void Release() = 0;
 
     virtual unsigned char* GetWritableData() = 0;
+
+    /// release the memory held and reset internal point to null.
+    /// After this function is invoked the PacketBuffer is unusable.
+    virtual void Destroy() = 0;
 };
 
 using IPacketBufferPtr = std::unique_ptr<IPacketBuffer>;
