@@ -5,6 +5,7 @@
 
 #pragma once
 
+#include <armnn/backends/profiling/IBackendProfiling.hpp>
 #include "ICounterDirectory.hpp"
 
 namespace armnn
@@ -16,7 +17,7 @@ namespace profiling
 class ISendCounterPacket
 {
 public:
-    using IndexValuePairsVector = std::vector<std::pair<uint16_t, uint32_t>>;
+    using IndexValuePairsVector = std::vector<CounterValue>;
 
     virtual ~ISendCounterPacket() {}
 
@@ -32,10 +33,6 @@ public:
     /// Create and write a PeriodicCounterSelectionPacket from the parameters to the buffer.
     virtual void SendPeriodicCounterSelectionPacket(uint32_t capturePeriod,
                                                     const std::vector<uint16_t>& selectedCounterIds) = 0;
-
-    /// Set a "ready to read" flag in the buffer to notify the reading thread to start reading it.
-    virtual void SetReadyToRead() = 0;
-
 };
 
 } // namespace profiling
