@@ -20,7 +20,7 @@ PacketBuffer::PacketBuffer(unsigned int maxSize)
     m_Data = std::make_unique<unsigned char[]>(m_MaxSize);
 }
 
-const unsigned char* const PacketBuffer::GetReadableData() const
+const unsigned char* PacketBuffer::GetReadableData() const
 {
     return m_Data.get();
 }
@@ -55,6 +55,13 @@ unsigned char* PacketBuffer::GetWritableData()
     return m_Data.get();
 }
 
+void PacketBuffer::Destroy()
+{
+    m_Data.reset(nullptr);
+    m_Size = 0;
+    m_MaxSize = 0;
+}
+
 } // namespace profiling
 
 } // namespace armnn
