@@ -22,7 +22,7 @@ public:
 
     ~PacketBuffer() {}
 
-    const unsigned char* const GetReadableData() const  override;
+    const unsigned char* GetReadableData() const  override;
 
     unsigned int GetSize() const  override;
 
@@ -34,6 +34,8 @@ public:
 
     unsigned char* GetWritableData() override;
 
+    void Destroy() override;
+
 private:
     unsigned int m_MaxSize;
     unsigned int m_Size;
@@ -42,4 +44,4 @@ private:
 
 } // namespace profiling
 
-} // namespace armnn
\ No newline at end of file
+} // namespace armnn
