@@ -7,6 +7,8 @@
 
 #include <atomic>
 
+#include <armnn/utility/IgnoreUnused.hpp>
+
 namespace armnn
 {
 
@@ -33,6 +35,7 @@ public:
 
     bool IsOneOfStates(ProfilingState state1)
     {
+        IgnoreUnused(state1);
         return false;
     }
 
