@@ -5,19 +5,20 @@
 
 #pragma once
 
-#include "CommandHandlerFunctor.hpp"
 #include "ISendCounterPacket.hpp"
-#include "ISendTimelinePacket.hpp"
-#include "Packet.hpp"
+#include "armnn/profiling/ISendTimelinePacket.hpp"
 #include "ProfilingStateMachine.hpp"
 
+#include <common/include/CommandHandlerFunctor.hpp>
+#include <common/include/Packet.hpp>
+
 namespace armnn
 {
 
 namespace profiling
 {
 
-class RequestCounterDirectoryCommandHandler : public CommandHandlerFunctor
+class RequestCounterDirectoryCommandHandler : public arm::pipe::CommandHandlerFunctor
 {
 
 public:
@@ -35,7 +36,7 @@ public:
         , m_StateMachine(profilingStateMachine)
     {}
 
-    void operator()(const Packet& packet) override;
+    void operator()(const arm::pipe::Packet& packet) override;
 
 private:
     const ICounterDirectory& m_CounterDirectory;
