@@ -1,11 +1,11 @@
 //
-// Copyright © 2019 Arm Ltd. All rights reserved.
+// Copyright © 2019 Arm Ltd and Contributors. All rights reserved.
 // SPDX-License-Identifier: MIT
 //
 
 #include "PeriodicCounterSelectionResponseHandler.hpp"
 
-#include "../../../src/profiling/ProfilingUtils.hpp"
+#include <common/include/CommonProfilingUtils.hpp>
 
 #include <iostream>
 
@@ -15,11 +15,11 @@ namespace armnn
 namespace gatordmock
 {
 
-void PeriodicCounterSelectionResponseHandler::operator()(const profiling::Packet& packet)
+void PeriodicCounterSelectionResponseHandler::operator()(const arm::pipe::Packet& packet)
 {
     if (!m_QuietOperation)    // Are we supposed to print to stdout?
     {
-        uint32_t period = profiling::ReadUint32(reinterpret_cast<const unsigned char*>(packet.GetData()), 0);
+        uint32_t period = arm::pipe::ReadUint32(reinterpret_cast<const unsigned char*>(packet.GetData()), 0);
         uint32_t numCounters = 0;
         // First check if there are any counters mentioned.
         if(packet.GetLength() > 4)
